# * ====================================================================
# * Copyright (c) 1995,1996, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# * 
# * With this file you should have received a file called 'License'.
# * 
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer. 
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================
#
# Module USMarc
#
# Defintions to facilitate display of USMarc records
#
# History:
#  1999-02-25  NWH   Initial release

package USMarc;

# FIXME It should be verified that this mapping file gives correct results.
#
%USMarc::mapping = (
   '010-a' => 'LC control number',
   '010-b' => 'NUCMC control number',
   '010-z' => 'Invalid LC control number',
   '011-a' => 'Linking LC control number',
   '013-6' => 'Linkage',
   '013-a' => 'Number',
   '013-b' => 'Country',
   '013-c' => 'Type of number',
   '013-d' => 'Date',
   '013-e' => 'Status',
   '013-f' => 'Party to document',
   '014-6' => 'Linkage',
   '014-a-auth' => 'Control number of bibl. record',
   '014-a-hold' => 'Linkage number',
   '014-b' => 'Source of number',
   '014-z' => 'Invalid linkage number',
   '015-6' => 'Linkage',
   '015-a' => 'Nat. bibl. number',
   '016-2' => 'Source',
   '016-a' => 'Record control number',
   '016-z-auth' => 'Invalid LC control number',
   '016-z-bibl' => 'Invalid record control number',
   '017-6' => 'Linkage',
   '017-a' => 'Copyright registration number',
   '017-b' => 'Source',
   '018-a' => 'Copyright article-fee code',
   '020-6' => 'Linkage',
   '020-a' => 'ISBN',
   '020-b' => 'Binding inform.',
   '020-c' => 'Terms of availability',
   '020-z' => 'Invalid ISBN',
   '022-6' => 'Linkage',
   '022-a' => 'ISSN',
   '022-y' => 'Incorrect ISSN',
   '022-z' => 'Cancelled ISSN',
   '024-2' => 'Source of code',
   '024-6' => 'Linkage',
   '024-a' => 'Std. recording code',
   '024-c' => 'Terms of availability',
   '024-d' => 'Add. codes following the std. code',
   '024-z' => 'Invalid std. code',
   '025-a' => 'Overseas acquisition number',
   '027-a' => 'Std. Techn. Report Number',
   '027-z' => 'Invalid STRN',
   '028-6' => 'Linkage',
   '028-a' => 'Publisher number',
   '028-b' => 'Source',
   '030-6' => 'Linkage',
   '030-a' => 'CODEN',
   '030-z' => 'Invalid CODEN',
   '032-6' => 'Linkage',
   '032-a' => 'Postal registration number',
   '032-b' => 'Source',
   '033-3' => 'Materials specified',
   '033-6' => 'Linkage',
   '033-a' => 'Formatted date/time',
   '033-b' => 'Geographic class. area code',
   '033-c' => 'Geographic class. subarea code',
   '034-6' => 'Linkage',
   '034-a' => 'Category of scale',
   '034-b' => 'Constant ratio linear horizontal scale',
   '034-c' => 'Constant ratio linear vertical scale',
   '034-d' => 'Westernmost longitude',
   '034-e' => 'Easternmost longitude',
   '034-f' => 'Northernmost latitude',
   '034-g' => 'Southernmost latitude',
   '034-h' => 'Angular scale',
   '034-j' => 'Declination--northern limit',
   '034-k' => 'Declination--southern limit',
   '034-m' => 'Right ascension--eastern limit',
   '034-n' => 'Right ascension--western limit',
   '034-p' => 'Equinox',
   '034-s' => 'G-ring latitude',
   '034-t' => 'G-ring longitude',
   '035-6' => 'Linkage',
   '035-a' => 'System control number',
   '035-z' => 'Invalid system control number',
   '036-6' => 'Linkage',
   '036-a' => 'Orig. study number',
   '036-b' => 'Source',
   '037-6' => 'Linkage',
   '037-a' => 'Stock number',
   '037-b' => 'Source of stock number/acquisition',
   '037-c' => 'Terms of availability',
   '037-f' => 'Form of issue',
   '037-g' => 'Add. format characteristics',
   '037-n' => 'Note',
   '039-a' => 'Level of rules in bibl. description',
   '039-b' => 'Level of effort used to assign nonsubject heading access points',
   '039-c' => 'Level of effort used to assign subject headings',
   '039-d' => 'Level of effort used to assign class.',
   '039-e' => 'Number of fixed field character positions coded',
   '040-6' => 'Linkage',
   '040-a-auth' => 'Orig. cataloging agency',
   '040-a-bibl' => 'Orig. cataloging agency',
   '040-a-clas' => 'Orig. class. agency',
   '040-a-comm' => 'Orig. agency',
   '040-b-auth' => 'Lang. of cataloging',
   '040-b-bibl' => 'Lang. of cataloging',
   '040-b-clas' => 'Lang. code',
   '040-b-comm' => 'Lang. code',
   '040-c' => 'Transcribing agency',
   '040-d' => 'Modifying agency',
   '040-e' => 'Description conventions',
   '040-f' => 'Subject heading/thesaurus conventions',
   '041-6' => 'Linkage',
   '041-a-bibl' => 'Lang. code of text/sound track or separate title',
   '041-a-comm' => 'Lang. code associated with community inform. entity',
   '041-b-bibl' => 'Lang. code of summary or abstract/overprinted title or subtitle',
   '041-b-comm' => 'Lang. code of supertitle or subtitle',
   '041-c' => 'Lang. of available translation',
   '041-d' => 'Lang. code of sung or spoken text',
   '041-e' => 'Lang. code of librettos',
   '041-f' => 'Lang. code of table of contents',
   '041-g' => 'Lang. code of accompanying material other than librettos',
   '041-h-bibl' => 'Lang. code of original and/or intermediate translations of text',
   '041-h-comm' => 'Lang. code of original',
   '042-a' => 'Authentication code',
   '043-2' => 'Source of local code',
   '043-a' => 'Geographic area code',
   '043-b' => 'Local GAC code',
   '044-2' => 'Source of local subentity code',
   '044-a' => 'Country of publishing/producing entity code',
   '044-b' => 'Local subentity code',
   '044-c' => 'ISO subentity code',
   '045-a' => 'Time period code',
   '045-b' => 'Formatted 9999 B.C. through A.D. time period',
   '045-c' => 'Formatted pre-9999 B.C. time period',
   '046-a' => 'Type of date code',
   '046-b' => 'Date 1',
   '046-c' => 'Date 1',
   '046-d' => 'Date 2',
   '046-e' => 'Date 2',
   '047-a' => 'Form of musical composition code',
   '048-a' => 'Performer or ensemble',
   '048-b' => 'Soloist',
   '050-3' => 'Materials specified',
   '050-5' => 'Institution to which field applies',
   '050-6' => 'Linkage',
   '050-a' => 'Class. number',
   '050-b' => 'Item number',
   '050-d-auth' => 'Volumes/dates to which call number applies',
   '050-d-bibl' => 'Supplementary class number',
   '051-a' => 'Class. number',
   '051-b' => 'Item number',
   '051-c' => 'Copy inform.',
   '052-a' => 'Geographic class. area code',
   '052-b' => 'Geographic class. subarea code',
   '052-c' => 'Subject',
   '053-5' => 'Institution to which field applies',
   '053-a' => 'Class. number element--single number or beginning number of span',
   '053-b' => 'Class. number element--ending number of span',
   '053-c' => 'Explanatory term',
   '055-2' => 'Source of call/class number',
   '055-5' => 'Institution to which field applies',
   '055-6' => 'Linkage',
   '055-a' => 'Class. number',
   '055-b' => 'Item number',
   '055-d' => 'Volumes/dates to which call number applies',
   '058-2' => 'Code source',
   '058-6' => 'Linkage',
   '058-a' => 'Geographic class. area code',
   '058-b' => 'Geographic class. subarea code',
   '060-5' => 'Institution to which field applies',
   '060-6' => 'Linkage',
   '060-a' => 'Class. number',
   '060-b' => 'Item number',
   '060-d' => 'Volumes/dates to which call number applies',
   '061-a' => 'Class. number',
   '061-b' => 'Item number',
   '061-c' => 'Copy inform.',
   '066-a' => 'Non-ASCII G0 default character set designation',
   '066-b' => 'Non-ANSEL G1 default character set designation',
   '066-c' => 'Alternate graphic character set identification',
   '070-6' => 'Linkage',
   '070-a' => 'Class. number',
   '070-b' => 'Item number',
   '070-d' => 'Volume/dates to which call number applies',
   '071-a' => 'Class. number',
   '071-b' => 'Item number',
   '071-c' => 'Copy inform.',
   '072-2' => 'Code source',
   '072-6' => 'Linkage',
   '072-a-auth' => 'Subject category code',
   '072-a-bibl' => 'Subject category code',
   '072-a-comm' => 'Human services code',
   '072-x-auth' => 'Subject category code subdivision',
   '072-x-bibl' => 'Subject category code subdivision',
   '072-x-comm' => 'Human services code subdivision',
   '073-2' => 'Code source',
   '073-6' => 'Linkage',
   '073-a-auth' => 'Subdivision usage',
   '073-a-comm' => 'Type of program or organization code',
   '073-z' => 'Source',
   '074-a' => 'GPO item number',
   '074-z' => 'Invalid GPO item number',
   '080-a' => 'Universal Decimal Class. number',
   '082-2' => 'Edition number',
   '082-5' => 'Institution to which field applies',
   '082-6' => 'Linkage',
   '082-a' => 'Class. number',
   '082-b-auth' => 'Item number',
   '082-b-bibl' => 'DDC number--abridged NST version',
   '082-b-comm' => 'Item number',
   '082-d' => 'Volumes/dates to which call number applies',
   '083-2' => 'Edition number',
   '083-5' => 'Institution to which field applies',
   '083-6' => 'Linkage',
   '083-a' => 'Class. number element--single number or beginning number of span',
   '083-b' => 'Class. number element--ending number of span',
   '083-c' => 'Explanatory term',
   '083-z' => 'Table identification--table number',
   '084-2' => 'Source of number',
   '084-6' => 'Linkage',
   '084-a-bibl' => 'Class. number',
   '084-a-clas' => 'Class. scheme code',
   '084-a-comm' => 'Class. number',
   '084-b-bibl' => 'Item number',
   '084-b-clas' => 'Edition title',
   '084-c' => 'Edition identifier',
   '084-e' => 'Lang. code',
   '086-2' => 'Number source',
   '086-5' => 'Institution to which field applies',
   '086-6' => 'Linkage',
   '086-a-auth' => 'Call number',
   '086-a-bibl' => 'Class. number',
   '086-d' => 'Volumes/dates to which call number applies',
   '086-z-auth' => 'Invalid call number',
   '086-z-bibl' => 'Invalid class. number',
   '087-2' => 'Number source',
   '087-a' => 'Class. number element--Single number or beginning number of span',
   '087-b' => 'Class. number element--Ending number of span',
   '087-c' => 'Explanatory inform.',
   '088-6' => 'Linkage',
   '088-a' => 'Report number',
   '088-z' => 'Invalid report number',
   '090-a-auth' => 'Class. number',
   '090-a-bibl' => 'Shelf location',
   '090-b-auth' => 'Item number',
   '090-b-bibl' => 'Local Cutter number',
   '090-d' => 'Volume/dates to which call number applies',
   '091-a' => 'Microfilm shelf location',
   '100-4' => 'Relator code',
   '100-6' => 'Linkage',
   '100-a' => 'Personal name',
   '100-b' => 'Numeration',
   '100-c' => 'Titles and other words associated with a name',
   '100-d' => 'Dates associated with a name',
   '100-e' => 'Relator term',
   '100-f' => 'Date of a work',
   '100-g' => 'Misc. inform.',
   '100-h' => 'Medium',
   '100-k' => 'Form subheading',
   '100-l' => 'Lang. of a work',
   '100-m' => 'Medium of performance for music',
   '100-n' => 'Number of part/section of a work',
   '100-o' => 'Arranged statement for music',
   '100-p' => 'Name of part/section of a work',
   '100-q' => 'Fuller form of name',
   '100-r' => 'Key for music',
   '100-s' => 'Version',
   '100-t' => 'Title of a work',
   '100-u' => 'Affiliation',
   '100-v' => 'Form subdivision',
   '100-x' => 'General subdivision',
   '100-y' => 'Chronological subdivision',
   '100-z' => 'Geographic subdivision',
   '110-4' => 'Relator code',
   '110-6' => 'Linkage',
   '110-a' => 'Corporate name or jurisdiction name as entry element',
   '110-b' => 'Subordinate unit',
   '110-c' => 'Location of meeting',
   '110-d-auth' => 'Date of meeting or treaty signing',
   '110-d-bibl' => 'Date of meeting or treaty signing',
   '110-d-comm' => 'Date of meeting',
   '110-e' => 'Relator term',
   '110-f' => 'Date of a work',
   '110-g' => 'Misc. inform.',
   '110-h' => 'Medium',
   '110-k' => 'Form subheading',
   '110-l' => 'Lang. of a work',
   '110-m' => 'Medium of performance for music',
   '110-n-auth' => 'Number of part/section/meeting',
   '110-n-bibl' => 'Number of part/section/meeting',
   '110-n-comm' => 'Number of meeting',
   '110-o' => 'Arranged statement for music',
   '110-p' => 'Name of part/section of a work',
   '110-r' => 'Key for music',
   '110-s' => 'Version',
   '110-t' => 'Title of a work',
   '110-u' => 'Affiliation',
   '110-v' => 'Form subdivision',
   '110-x' => 'General subdivision',
   '110-y' => 'Chronological subdivision',
   '110-z' => 'Geographic subdivision',
   '111-4' => 'Relator code',
   '111-6' => 'Linkage',
   '111-a' => 'Meeting name or jurisdiction name as entry element',
   '111-b' => 'Number',
   '111-c' => 'Location of meeting',
   '111-d' => 'Date of meeting',
   '111-e' => 'Subordinate unit',
   '111-f' => 'Date of a work',
   '111-g' => 'Misc. inform.',
   '111-h' => 'Medium',
   '111-k' => 'Form subheading',
   '111-l' => 'Lang. of a work',
   '111-n-auth' => 'Number of part/section/meeting',
   '111-n-bibl' => 'Number of part/section/meeting',
   '111-n-comm' => 'Number of meeting',
   '111-p' => 'Name of part/section of a work',
   '111-q' => 'Name of meeting following jurisdiction name entry element',
   '111-s' => 'Version',
   '111-t' => 'Title of a work',
   '111-u' => 'Affiliation',
   '111-v' => 'Form subdivision',
   '111-x' => 'General subdivision',
   '111-y' => 'Chronological subdivision',
   '111-z' => 'Geographic subdivision',
   '130-6' => 'Linkage',
   '130-a' => 'Uniform title',
   '130-d' => 'Date of treaty signing',
   '130-f' => 'Date of a work',
   '130-g' => 'Misc. inform.',
   '130-h' => 'Medium',
   '130-k' => 'Form subheading',
   '130-l' => 'Lang. of a work',
   '130-m' => 'Medium of performance for music',
   '130-n' => 'Number of part/section of a work',
   '130-o' => 'Arranged statement for music',
   '130-p' => 'Name of part/section of a work',
   '130-r' => 'Key for music',
   '130-s' => 'Version',
   '130-t' => 'Title of a work',
   '130-v' => 'Form subdivision',
   '130-x' => 'General subdivision',
   '130-y' => 'Chronological subdivision',
   '130-z' => 'Geographic subdivision',
   '150-6' => 'Linkage',
   '150-a' => 'Topical term or geographic name as entry element',
   '150-b' => 'Topical term following geographic name as entry element',
   '150-v' => 'Form subdivision',
   '150-x' => 'General subdivision',
   '150-y' => 'Chronological subdivision',
   '150-z' => 'Geographic subdivision',
   '151-6' => 'Linkage',
   '151-a' => 'Geographic name',
   '151-b' => 'Name following place as entry element',
   '151-v' => 'Form subdivision',
   '151-x' => 'General subdivision',
   '151-y' => 'Chronological subdivision',
   '151-z' => 'Geographic subdivision',
   '153-a' => 'Class. number element--single number or beginning number of span',
   '153-c' => 'Class. number element--ending number of span',
   '153-h' => 'Caption hierarchy',
   '153-j' => 'Caption',
   '153-k' => 'Summary number span caption hierarchy',
   '153-z' => 'Table identification',
   '154-a' => 'General explanatory index term',
   '154-b' => 'General explanatory index term--succeeding level',
   '154-f' => 'Schedule identification',
   '155-6' => 'Linkage',
   '155-a' => 'Genre/form term',
   '155-v' => 'Form subdivision',
   '155-x' => 'General subdivision',
   '155-y' => 'Chronological subdivision',
   '155-z' => 'Geographic subdivision',
   '180-6' => 'Linkage',
   '180-v' => 'Form subdivision',
   '180-x' => 'General subdivision',
   '180-y' => 'Chronological subdivision',
   '180-z' => 'Geographic subdivision',
   '181-6' => 'Linkage',
   '181-v' => 'Form subdivision',
   '181-x' => 'General subdivision',
   '181-y' => 'Chronological subdivision',
   '181-z' => 'Geographic subdivision',
   '182-6' => 'Linkage',
   '182-v' => 'Form subdivision',
   '182-x' => 'General subdivision',
   '182-y' => 'Chronological subdivision',
   '182-z' => 'Geographic subdivision',
   '185-6' => 'Linkage',
   '185-v' => 'Form subdivision',
   '185-x' => 'General subdivision',
   '185-y' => 'Chronological subdivision',
   '185-z' => 'Geographic subdivision',
   '210-6' => 'Linkage',
   '210-a' => 'Abbreviated title',
   '210-b' => 'Qualifying inform.',
   '211-6' => 'Linkage',
   '211-a' => 'Acronym or shortened title',
   '212-6' => 'Linkage',
   '212-a' => 'Variant access title',
   '214-6' => 'Linkage',
   '214-a' => 'Augmented title',
   '222-6' => 'Linkage',
   '222-a' => 'Key title',
   '222-b' => 'Qualifying inform.',
   '240-6' => 'Linkage',
   '240-a' => 'Uniform title',
   '240-d' => 'Date of treaty signing',
   '240-f' => 'Date of a work',
   '240-g' => 'Misc. inform.',
   '240-h' => 'Medium',
   '240-k' => 'Form subheading',
   '240-l' => 'Lang. of a work',
   '240-m' => 'Medium of performance for music',
   '240-n' => 'Number of part/section of a work',
   '240-o' => 'Arranged statement for music',
   '240-p' => 'Name of part/section of a work',
   '240-r' => 'Key for music',
   '240-s' => 'Version',
   '241-a' => 'Romanized title',
   '241-h' => 'Medium',
   '242-6' => 'Linkage',
   '242-a' => 'Title',
   '242-b' => 'Remainder of title',
   '242-c' => 'Remainder of title page',
   '242-d' => 'Designation of section',
   '242-e' => 'Name of part/section',
   '242-h' => 'Medium',
   '242-n' => 'Number of part/section of a work',
   '242-p' => 'Name of part/section of a work',
   '242-y' => 'Lang. code of translated title',
   '243-6' => 'Linkage',
   '243-a' => 'Uniform title',
   '243-d' => 'Date of treaty signing',
   '243-f' => 'Date of a work',
   '243-g' => 'Misc. inform.',
   '243-h' => 'Medium',
   '243-k' => 'Form subheading',
   '243-l' => 'Lang. of a work',
   '243-m' => 'Medium of performance for music',
   '243-n' => 'Number of part/section of a work',
   '243-o' => 'Arranged statement for music',
   '243-p' => 'Name of part/section of a work',
   '243-r' => 'Key for music',
   '243-s' => 'Version',
   '245-6' => 'Linkage',
   '245-a' => 'Title',
   '245-b' => 'Remainder of title',
   '245-c-bibl' => 'Remainder of title page',
   '245-c-comm' => 'Remainder of field data',
   '245-d' => 'Designation of section',
   '245-e' => 'Name of part/section',
   '245-f' => 'Inclusive dates',
   '245-g' => 'Bulk dates',
   '245-h' => 'Medium',
   '245-k' => 'Form',
   '245-n-bibl' => 'Number of part/section of a work',
   '245-n-comm' => 'Number of part/section of the title',
   '245-p-bibl' => 'Name of part/section of a work',
   '245-p-comm' => 'Name of part/section of the title',
   '245-s' => 'Version',
   '246-5' => 'Institution to which field applies',
   '246-6' => 'Linkage',
   '246-a-bibl' => 'Title proper/short title',
   '246-a-comm' => 'Variant title',
   '246-b' => 'Remainder of title',
   '246-d' => 'Designation of section',
   '246-e' => 'Name of part/section',
   '246-f-bibl' => 'Designation of volume and issue number and/or date of a work',
   '246-f-comm' => 'Dates of title use',
   '246-g' => 'Misc. inform.',
   '246-h' => 'Medium',
   '246-i' => 'Display text',
   '246-n-bibl' => 'Number of part/section of a work',
   '246-n-comm' => 'Number of part/section of the title',
   '246-p-bibl' => 'Name of part/section of a work',
   '246-p-comm' => 'Name of part/section of the title',
   '247-6' => 'Linkage',
   '247-a-bibl' => 'Title proper/short title',
   '247-a-comm' => 'Former title',
   '247-b' => 'Remainder of title',
   '247-d' => 'Designation of section',
   '247-e' => 'Name of part/section',
   '247-f-bibl' => 'Designation of volume and issue number and/or date of a work',
   '247-f-comm' => 'Dates of title use',
   '247-g' => 'Misc. inform.',
   '247-h' => 'Medium',
   '247-n-bibl' => 'Number of part/section of a work',
   '247-n-comm' => 'Number of part/section of the title',
   '247-p-bibl' => 'Name of part/section of a work',
   '247-p-comm' => 'Name of part/section of the title',
   '247-x' => 'ISSN',
   '253-a' => 'Class. number referred to--single number or beginning number of span',
   '253-c' => 'Class. number referred to--ending number of span',
   '253-i' => 'Explanatory text',
   '253-y' => 'Table identification--schedule',
   '253-z' => 'Table identification',
   '254-6' => 'Linkage',
   '254-a' => 'Musical presentation statement',
   '255-6' => 'Linkage',
   '255-a' => 'Statement of scale',
   '255-b' => 'Statement of projection',
   '255-c' => 'Statement of coordinates',
   '255-d' => 'Statement of zone',
   '255-e' => 'Statement of equinox',
   '255-f' => 'Outer G-ring coordinate pairs',
   '255-g' => 'Exclusion G-ring coordinate pairs',
   '256-6' => 'Linkage',
   '256-a' => 'Computer file characteristics',
   '257-6' => 'Linkage',
   '257-a' => 'Country of producing entity for archival films',
   '260-6' => 'Linkage',
   '260-a-auth' => 'Heading referred to',
   '260-a-bibl' => 'Place of publication, distribution, etc.',
   '260-b' => 'Name of publisher, distributor, etc.',
   '260-c' => 'Date of publication, distribution, etc.',
   '260-d' => 'Plates of publisher\'s number for music',
   '260-e' => 'Place of manufacture',
   '260-f' => 'Manufacturer',
   '260-g' => 'Date of manufacture',
   '260-i' => 'Explanatory text',
   '261-6' => 'Linkage',
   '261-a' => 'Producing company',
   '261-b' => 'Releasing company',
   '261-d' => 'Date of production, release, etc.',
   '261-e' => 'Contractual producer',
   '261-f' => 'Place of production, release, etc.',
   '262-6' => 'Linkage',
   '262-a' => 'Place of production, release, etc.',
   '262-b' => 'Publisher or trade name',
   '262-c' => 'Date of production, release, etc.',
   '262-k' => 'Serial identification',
   '262-l' => 'Matrix and/or take number',
   '263-a' => 'Projected publication date',
   '265-6' => 'Linkage',
   '265-a' => 'Source for acquisition/subscription address',
   '270-4' => 'Relator code',
   '270-6' => 'Linkage',
   '270-a' => 'Address',
   '270-b' => 'City',
   '270-c' => 'State or province',
   '270-d' => 'Country',
   '270-e' => 'Postal code',
   '270-f' => 'Title preceding attention name',
   '270-g' => 'Attention name',
   '270-h' => 'Title following attention name',
   '270-i' => 'Type of address',
   '270-j' => 'Specialized telephone number',
   '270-k' => 'Telephone number',
   '270-l' => 'Fax number',
   '270-m' => 'Electronic mail address',
   '270-n' => 'TDD or TTY number',
   '270-p' => 'Contact person',
   '270-q' => 'Title of contact person',
   '270-r' => 'Hours',
   '270-z' => 'Public note',
   '271-6' => 'Linkage',
   '271-a' => 'Address',
   '271-b' => 'City',
   '271-c' => 'State or province',
   '271-d' => 'Country',
   '271-e' => 'Postal code',
   '271-f' => 'Title preceding attention name',
   '271-g' => 'Attention name',
   '271-h' => 'Title following attention name',
   '271-i' => 'Type of address',
   '271-j' => 'Specialized telephone number',
   '271-k' => 'Telephone number',
   '271-l' => 'Fax number',
   '271-m' => 'Electronic mail address',
   '271-n' => 'TDD or TTY number',
   '271-p' => 'Contact person',
   '271-q' => 'Title of contact person',
   '275-6' => 'Linkage',
   '275-a' => 'Address',
   '275-b' => 'City',
   '275-c' => 'State or province',
   '275-d' => 'Country',
   '275-e' => 'Postal code',
   '275-f' => 'Title preceding attention name',
   '275-g' => 'Attention name',
   '275-h' => 'Title following attention name',
   '275-i' => 'Type of address',
   '275-j' => 'Specialized telephone number',
   '275-k' => 'Telephone number',
   '275-l' => 'Fax number',
   '275-m' => 'Electronic mail address',
   '275-n' => 'TDD or TTY number',
   '275-p' => 'Contact person',
   '275-q' => 'Title of contact person',
   '300-3' => 'Materials specified',
   '300-6' => 'Linkage',
   '300-a' => 'Extent',
   '300-b' => 'Other physical details',
   '300-c' => 'Dimensions',
   '300-e' => 'Accompanying material',
   '300-f' => 'Type of unit',
   '300-g' => 'Size of unit',
   '301-6' => 'Linkage',
   '301-a-bibl' => 'Extent of item',
   '301-a-comm' => 'Hours',
   '301-b-bibl' => 'Sound characteristics',
   '301-b-comm' => 'Add. inform.',
   '301-c' => 'Color characteristics',
   '301-d' => 'Dimensions',
   '301-e' => 'Accompanying material',
   '301-f' => 'Speed',
   '302-a' => 'Page count',
   '303-6' => 'Linkage',
   '303-a-bibl' => 'Unit count',
   '303-a-comm' => 'Name or description',
   '303-b' => 'Schedule',
   '303-c' => 'Location',
   '303-p' => 'Contact person',
   '304-a' => 'Linear footage',
   '305-6' => 'Linkage',
   '305-a' => 'Extent',
   '305-b' => 'Other physical details',
   '305-c' => 'Dimensions',
   '305-d' => 'Microgroove or std.',
   '305-e' => 'Stereophonic, monaural',
   '305-f' => 'Number of tracks',
   '305-m' => 'Serial identification',
   '305-n' => 'Matrix and/or take number',
   '306-a' => 'Playing time',
   '307-6' => 'Linkage',
   '307-a' => 'Hours',
   '307-b' => 'Add. inform.',
   '308-6' => 'Linkage',
   '308-a' => 'Number of reels',
   '308-b' => 'Footage',
   '308-c' => 'Sound characteristics',
   '308-d' => 'Color characteristics',
   '308-e' => 'Width',
   '308-f' => 'Presentation format',
   '310-6' => 'Linkage',
   '310-a' => 'Current publication frequency',
   '310-b' => 'Date of current publication frequency',
   '311-6' => 'Linkage',
   '311-a' => 'General description of facilities',
   '311-b' => 'Name and location',
   '311-c' => 'Physical description',
   '311-d' => 'Capacity',
   '311-e' => 'Equipment available',
   '311-f' => 'Rental fee',
   '311-g' => 'Special restrictions',
   '311-h' => 'Accommodations for the disabled',
   '311-m' => 'Misc. inform.',
   '311-p' => 'Contact person',
   '312-6' => 'Linkage',
   '312-a' => 'Type of equipment',
   '312-b' => 'Brand name',
   '312-c' => 'Physical description',
   '312-f' => 'Rental fee',
   '312-g' => 'Special restrictions',
   '312-h' => 'Accommodations for the disabled',
   '312-m' => 'Misc. inform.',
   '312-p' => 'Contact person',
   '315-6' => 'Linkage',
   '315-a' => 'Frequency',
   '315-b' => 'Dates of frequency',
   '321-6' => 'Linkage',
   '321-a' => 'Former publication frequency',
   '321-b' => 'Dates of former publication frequency',
   '340-3' => 'Materials specified',
   '340-6' => 'Linkage',
   '340-a' => 'Material base and configuration',
   '340-b' => 'Dimensions',
   '340-c' => 'Materials applied to surface',
   '340-d' => 'Information recording technique',
   '340-e' => 'Support',
   '340-f' => 'Production rate/ratio',
   '340-h' => 'Location within medium',
   '340-i' => 'Techn. specifications of medium',
   '342-2' => 'Reference method used',
   '342-6' => 'Linkage',
   '342-a' => 'Name',
   '342-b' => 'Coordinate or distance units',
   '342-c' => 'Latitude resolution',
   '342-d' => 'Longitude resolution',
   '342-e' => 'Std. parallel or oblique line latitude',
   '342-f' => 'Oblique line longitude',
   '342-g' => 'Longitude of central meridian or projection center',
   '342-h' => 'Latitude of projection origin or projection center',
   '342-i' => 'False easting',
   '342-j' => 'False northing',
   '342-k' => 'Scale factor',
   '342-l' => 'Height of perspective point above surface',
   '342-m' => 'Azimuthal angle',
   '342-n' => 'Azimuth measure point longitude or straight vertical longitude from pole',
   '342-o' => 'Landsat number and path number',
   '342-p' => 'Zone identifier',
   '342-q' => 'Ellipsoid name',
   '342-r' => 'Semi-major axis',
   '342-s' => 'Denominator of flattening ratio',
   '342-t' => 'Vertical resolution',
   '342-u' => 'Vertical encoding method',
   '342-v' => 'Local planar, local, or other projection or grid description',
   '342-w' => 'Local planar or local georeference inform.',
   '343-6' => 'Linkage',
   '343-a' => 'Planar coordinate encoding method',
   '343-b' => 'Planar distance units',
   '343-c' => 'Abscissa resolution',
   '343-d' => 'Ordinate resolution',
   '343-e' => 'Distance resolution',
   '343-f' => 'Bearing resolution',
   '343-g' => 'Bearing units',
   '343-h' => 'Bearing reference direction',
   '343-i' => 'Bearing reference meridian',
   '350-6' => 'Linkage',
   '350-a' => 'Price',
   '350-b' => 'Form of issue',
   '351-3' => 'Materials specified',
   '351-6' => 'Linkage',
   '351-a' => 'Organization',
   '351-b' => 'Arrangement',
   '351-c' => 'Hierarchical level',
   '352-6' => 'Linkage',
   '352-a' => 'Direct reference method',
   '352-b' => 'Object type',
   '352-c' => 'Object count',
   '352-d' => 'Row count',
   '352-e' => 'Column count',
   '352-g' => 'Vertical count',
   '352-i' => 'Indirect reference description',
   '353-a' => 'Class. number referred to--single number or beginning number of span',
   '353-c' => 'Class. number referred to--ending number of span',
   '353-i' => 'Explanatory text',
   '353-y' => 'Table identification--schedule',
   '353-z' => 'Table identification',
   '355-6' => 'Linkage',
   '355-a' => 'Security class.',
   '355-b' => 'Handling instructions',
   '355-c' => 'External dissemination inform.',
   '355-d' => 'Downgrading or declass. event',
   '355-e' => 'Class. system',
   '355-f' => 'Country of origin code',
   '355-g' => 'Downgrading date',
   '355-h' => 'Declass. date',
   '355-j' => 'Authorization',
   '357-6' => 'Linkage',
   '357-a' => 'Originator control term',
   '357-b' => 'Orig. agency',
   '357-c' => 'Auth. recipients of material',
   '357-g' => 'Other restrictions',
   '359-a' => 'Rental price',
   '360-6' => 'Linkage',
   '360-a' => 'Heading referred to',
   '360-i' => 'Explanatory text',
   '362-6' => 'Linkage',
   '362-a' => 'Dates of publication and/or sequential designation',
   '362-z' => 'Source of inform.',
   '400-4' => 'Relator code',
   '400-5' => 'Institution to which field applies',
   '400-6' => 'Linkage',
   '400-a' => 'Personal name',
   '400-b' => 'Numeration',
   '400-c' => 'Titles and other words associated with a name',
   '400-d' => 'Dates associated with a name',
   '400-e' => 'Relator term',
   '400-f' => 'Date of a work',
   '400-g' => 'Misc. inform.',
   '400-h' => 'Medium',
   '400-i' => 'Reference instruction phrase',
   '400-k' => 'Form subheading',
   '400-l' => 'Lang. of a work',
   '400-m' => 'Medium of performance for music',
   '400-n' => 'Number of part/section of a work',
   '400-o' => 'Arranged statement for music',
   '400-p' => 'Name of part/section of a work',
   '400-q' => 'Fuller form of name',
   '400-r' => 'Key for music',
   '400-s' => 'Version',
   '400-t' => 'Title of a work',
   '400-u' => 'Affiliation',
   '400-v-auth' => 'Form subdivision',
   '400-v-bibl' => 'Volume number/sequential designation',
   '400-w' => 'Control subfield',
   '400-x-auth' => 'General subdivision',
   '400-x-bibl' => 'ISSN',
   '400-y' => 'Chronological subdivision',
   '400-z' => 'Geographic subdivision',
   '410-4' => 'Relator code',
   '410-5' => 'Institution to which field applies',
   '410-6' => 'Linkage',
   '410-a' => 'Corporate name or jurisdiction name as entry element',
   '410-b' => 'Subordinate unit',
   '410-c' => 'Location of meeting',
   '410-d' => 'Date of meeting or treaty signing',
   '410-e' => 'Relator term',
   '410-f' => 'Date of a work',
   '410-g' => 'Misc. inform.',
   '410-h' => 'Medium',
   '410-i' => 'Explanatory text',
   '410-k' => 'Form subheading',
   '410-l' => 'Lang. of a work',
   '410-m' => 'Medium of performance for music',
   '410-n' => 'Number of part/section/meeting',
   '410-o' => 'Arranged statement for music',
   '410-p' => 'Name of part/section of a work',
   '410-r' => 'Key for music',
   '410-s' => 'Version',
   '410-t' => 'Title of a work',
   '410-u' => 'Affiliation',
   '410-v-auth' => 'Form subdivision',
   '410-v-bibl' => 'Volume number/sequential designation',
   '410-w' => 'Control subfield',
   '410-x-auth' => 'General subdivision',
   '410-x-bibl' => 'ISSN',
   '410-y' => 'Chronological subdivision',
   '410-z' => 'Geographic subdivision',
   '411-4' => 'Relator code',
   '411-5' => 'Institution to which field applies',
   '411-6' => 'Linkage',
   '411-a' => 'Meeting name or jurisdiction name as entry element',
   '411-b' => 'Number',
   '411-c' => 'Location of meeting',
   '411-d' => 'Date of meeting',
   '411-e' => 'Subordinate unit',
   '411-f' => 'Date of a work',
   '411-g' => 'Misc. inform.',
   '411-h' => 'Medium',
   '411-i' => 'Reference instruction phrase',
   '411-k' => 'Form subheading',
   '411-l' => 'Lang. of a work',
   '411-n' => 'Number of part/section/meeting',
   '411-p' => 'Name of part/section of a work',
   '411-q' => 'Name of meeting following jurisdiction name entry element',
   '411-s' => 'Version',
   '411-t' => 'Title of a work',
   '411-u' => 'Affiliation',
   '411-v-auth' => 'Form subdivision',
   '411-v-bibl' => 'Volume number/sequential designation',
   '411-w' => 'Control subfield',
   '411-x-auth' => 'General subdivision',
   '411-x-bibl' => 'ISSN',
   '411-y' => 'Chronological subdivision',
   '411-z' => 'Geographic subdivision',
   '430-5' => 'Institution to which field applies',
   '430-6' => 'Linkage',
   '430-a' => 'Uniform title',
   '430-d' => 'Date of treaty signing',
   '430-f' => 'Date of a work',
   '430-g' => 'Misc. inform.',
   '430-h' => 'Medium',
   '430-i' => 'Reference instruction phrase',
   '430-k' => 'Form subheading',
   '430-l' => 'Lang. of a work',
   '430-m' => 'Medium of performance for music',
   '430-n' => 'Number of part/section of a work',
   '430-o' => 'Arranged statement for music',
   '430-p' => 'Name of part/section of a work',
   '430-r' => 'Key for music',
   '430-s' => 'Version',
   '430-t' => 'Title of a work',
   '430-v' => 'Form subdivision',
   '430-w' => 'Control subfield',
   '430-x' => 'General subdivision',
   '430-y' => 'Chronological subdivision',
   '430-z' => 'Geographic subdivision',
   '440-6' => 'Linkage',
   '440-a' => 'Title',
   '440-n-bibl' => 'Number of part/section of a work',
   '440-n-comm' => 'Number of part/section',
   '440-p-bibl' => 'Name of part/section of a work',
   '440-p-comm' => 'Name of part/section',
   '440-v-bibl' => 'Volume number/sequential designation',
   '440-v-comm' => 'Sequential designation',
   '440-x' => 'ISSN',
   '450-5' => 'Institution to which field applies',
   '450-6' => 'Linkage',
   '450-a' => 'Topical term or geographic name as entry element',
   '450-b' => 'Topical term following geographic name as entry element',
   '450-i' => 'Reference instruction phrase',
   '450-v' => 'Form subdivision',
   '450-w' => 'Control subfield',
   '450-x' => 'General subdivision',
   '450-y' => 'Chronological subdivision',
   '450-z' => 'Geographic subdivision',
   '451-5' => 'Institution to which field applies',
   '451-6' => 'Linkage',
   '451-a' => 'Geographic name',
   '451-b' => 'Name following place as entry element',
   '451-i' => 'Reference instruction phrase',
   '451-v' => 'Form subdivision',
   '451-w' => 'Control subfield',
   '451-x' => 'General subdivision',
   '451-y' => 'Chronological subdivision',
   '451-z' => 'Geographic subdivision',
   '453-a' => 'Class. number element--single number or beginning number of span',
   '453-c' => 'Class. number element--ending number of span',
   '453-h' => 'Caption hierarchy',
   '453-i' => 'Reference instruction phrase',
   '453-j' => 'Caption',
   '453-k' => 'Summary number span caption hierarchy',
   '453-t' => 'Topic',
   '453-w' => 'Control subfield',
   '453-y' => 'Table identification--schedule',
   '453-z' => 'Table identification',
   '455-5' => 'Institution to which field applies',
   '455-6' => 'Linkage',
   '455-a' => 'Genre/form term',
   '455-i' => 'Reference instruction phrase',
   '455-v' => 'Form subdivision',
   '455-w' => 'Control subfield',
   '455-x' => 'General subdivision',
   '455-y' => 'Chronological subdivision',
   '455-z' => 'Geographic subdivision',
   '480-5' => 'Institution to which field applies',
   '480-6' => 'Linkage',
   '480-i' => 'Reference instruction phrase',
   '480-v' => 'Form subdivision',
   '480-w' => 'Control subfield',
   '480-x' => 'General subdivision',
   '480-y' => 'Chronological subdivision',
   '480-z' => 'Geographic subdivision',
   '481-5' => 'Institution to which field applies',
   '481-6' => 'Linkage',
   '481-i' => 'Reference instruction phrase',
   '481-v' => 'Form subdivision',
   '481-w' => 'Control subfield',
   '481-x' => 'General subdivision',
   '481-y' => 'Chronological subdivision',
   '481-z' => 'Geographic subdivision',
   '482-5' => 'Institution to which field applies',
   '482-6' => 'Linkage',
   '482-i' => 'Reference instruction phrase',
   '482-v' => 'Form subdivision',
   '482-w' => 'Control subfield',
   '482-x' => 'General subdivision',
   '482-y' => 'Chronological subdivision',
   '482-z' => 'Geographic subdivision',
   '485-5' => 'Institution to which field applies',
   '485-6' => 'Linkage',
   '485-i' => 'Reference instruction phrase',
   '485-v' => 'Form subdivision',
   '485-w' => 'Control subfield',
   '485-x' => 'General subdivision',
   '485-y' => 'Chronological subdivision',
   '485-z' => 'Geographic subdivision',
   '490-6' => 'Linkage',
   '490-a' => 'Series statement',
   '490-l' => 'Library of Congress call number',
   '490-v' => 'Volume number/sequential designation',
   '490-x' => 'ISSN',
   '500-0' => 'Record control number',
   '500-3' => 'Materials specified',
   '500-5' => 'Institution to which field applies',
   '500-6' => 'Linkage',
   '500-a-auth' => 'Personal name',
   '500-a-bibl' => 'General note',
   '500-a-comm' => 'General note',
   '500-b' => 'Numeration',
   '500-c' => 'Titles and other words associated with a name',
   '500-d' => 'Dates associated with a name',
   '500-e' => 'Relator term',
   '500-f' => 'Date of a work',
   '500-g' => 'Misc. inform.',
   '500-h' => 'Medium',
   '500-i' => 'Reference instruction phrase',
   '500-k' => 'Form subheading',
   '500-l-auth' => 'Lang. of a work',
   '500-l-bibl' => 'Library of Congress call number',
   '500-m' => 'Medium of performance for music',
   '500-n' => 'Number of part/section of a work',
   '500-o' => 'Arranged statement for music',
   '500-p' => 'Name of part/section of a work',
   '500-q' => 'Fuller form of name',
   '500-r' => 'Key for music',
   '500-s' => 'Version',
   '500-t' => 'Title of a work',
   '500-v' => 'Form subdivision',
   '500-w' => 'Control subfield',
   '500-x-auth' => 'General subdivision',
   '500-x-bibl' => 'ISSN',
   '500-y' => 'Chronological subdivision',
   '500-z-auth' => 'Geographic subdivision',
   '500-z-bibl' => 'Source of note inform.',
   '501-5' => 'Institution to which field applies',
   '501-6' => 'Linkage',
   '501-a-bibl' => 'With note',
   '501-a-comm' => 'Currency of inform. note',
   '502-6' => 'Linkage',
   '502-a' => 'Dissertation note',
   '503-6' => 'Linkage',
   '503-a' => 'Bibliographic history note',
   '504-6' => 'Linkage',
   '504-a' => 'Bibliography, etc. note',
   '504-b' => 'Number of references',
   '505-6' => 'Linkage',
   '505-a-bibl' => 'Formatted contents note',
   '505-a-comm' => 'Specific programs note',
   '505-g' => 'Misc. inform.',
   '505-r' => 'Statement of responsibility',
   '505-t' => 'Title',
   '506-3' => 'Materials specified',
   '506-5' => 'Institution to which field applies',
   '506-6' => 'Linkage',
   '506-a' => 'Terms governing access',
   '506-b' => 'Jurisdiction',
   '506-c' => 'Physical access provisions',
   '506-d' => 'Auth. users',
   '506-e' => 'Authorization',
   '507-6' => 'Linkage',
   '507-a' => 'Representative fraction of scale note',
   '507-b' => 'Remainder of scale note',
   '508-6' => 'Linkage',
   '508-a' => 'Creation/production credits note',
   '510-0' => 'Record control number',
   '510-3' => 'Materials specified',
   '510-5' => 'Institution to which field applies',
   '510-6' => 'Linkage',
   '510-a-auth' => 'Corporate name or jurisdiction name as entry element',
   '510-a-bibl' => 'Name of source',
   '510-b-auth' => 'Subordinate unit',
   '510-b-bibl' => 'Dates of coverage of source',
   '510-c-auth' => 'Location of meeting',
   '510-c-bibl' => 'Location within source',
   '510-d' => 'Date of meeting or treaty signing',
   '510-e' => 'Relator term',
   '510-f' => 'Date of a work',
   '510-g' => 'Misc. inform.',
   '510-h' => 'Medium',
   '510-i' => 'Reference instruction phrase',
   '510-k' => 'Form subheading',
   '510-l' => 'Lang. of a work',
   '510-m' => 'Medium of performance for music',
   '510-n' => 'Number of part/section/meeting',
   '510-o' => 'Arranged statement for music',
   '510-p' => 'Name of part/section of a work',
   '510-r' => 'Key for music',
   '510-s' => 'Version',
   '510-t' => 'Title of a work',
   '510-v' => 'Form subdivision',
   '510-w' => 'Control subfield',
   '510-x-auth' => 'General subdivision',
   '510-x-bibl' => 'ISSN',
   '510-y' => 'Chronological subdivision',
   '510-z' => 'Geographic subdivision',
   '511-0' => 'Record control number',
   '511-5' => 'Institution to which field applies',
   '511-6' => 'Linkage',
   '511-a-auth' => 'Meeting name or jurisdiction name as entry element',
   '511-a-bibl' => 'Participant or performer note',
   '511-a-comm' => 'Participant or performer note',
   '511-b' => 'Number',
   '511-c' => 'Location of meeting',
   '511-d' => 'Date of meeting',
   '511-e' => 'Subordinate unit',
   '511-f' => 'Date of a work',
   '511-g' => 'Misc. inform.',
   '511-h' => 'Medium',
   '511-i' => 'Reference instruction phrase',
   '511-k' => 'Form subheading',
   '511-l' => 'Lang. of a work',
   '511-n' => 'Number of part/section/meeting',
   '511-p' => 'Name of part/section of a work',
   '511-q' => 'Name of meeting following jurisdiction name entry element',
   '511-s' => 'Version',
   '511-t' => 'Title of a work',
   '511-v' => 'Form subdivision',
   '511-w' => 'Control subfield',
   '511-x' => 'General subdivision',
   '511-y' => 'Chronological subdivision',
   '511-z' => 'Geographic subdivision',
   '512-6' => 'Linkage',
   '512-a' => 'Earlier or later volumes separately cataloged note',
   '513-6' => 'Linkage',
   '513-a' => 'Type of report',
   '513-b' => 'Period covered',
   '514-6' => 'Linkage',
   '514-a' => 'Attribute accuracy report',
   '514-b' => 'Attribute accuracy value',
   '514-c' => 'Attribute accuracy explanation',
   '514-d' => 'Logical consistency report',
   '514-e' => 'Completeness report',
   '514-f' => 'Horizontal position accuracy report',
   '514-g' => 'Horizontal position accuracy value',
   '514-h' => 'Horizontal position accuracy explanation',
   '514-i' => 'Vertical positional accuracy report',
   '514-j' => 'Vertical positional accuracy value',
   '514-k' => 'Vertical positional accuracy explanation',
   '514-m' => 'Cloud cover',
   '515-6' => 'Linkage',
   '515-a' => 'Numbering peculiarities note',
   '515-z' => 'Source of note inform.',
   '516-6' => 'Linkage',
   '516-a' => 'Type of computer file or data note',
   '517-a' => 'Different formats',
   '517-b' => 'Content descriptors',
   '517-c' => 'Add. animation techniques',
   '518-3' => 'Materials specified',
   '518-6' => 'Linkage',
   '518-a' => 'Date/time and place of an event note',
   '520-3' => 'Materials specified',
   '520-6' => 'Linkage',
   '520-a-bibl' => 'Summary note',
   '520-a-comm' => 'Description note',
   '520-b' => 'Expansion of summary note',
   '520-z' => 'Source of note inform.',
   '521-3' => 'Materials specified',
   '521-6' => 'Linkage',
   '521-a-bibl' => 'Target audience note',
   '521-a-comm' => 'Target group note',
   '521-b' => 'Source',
   '522-6' => 'Linkage',
   '522-a-bibl' => 'Geographic coverage note',
   '522-a-comm' => 'Geographic area note',
   '523-6' => 'Linkage',
   '523-a' => 'Time period of content note',
   '523-b' => 'Dates of data collection note',
   '524-2' => 'Source of schema used',
   '524-3' => 'Materials specified',
   '524-6' => 'Linkage',
   '524-a' => 'Preferred citation of described materials note',
   '525-6' => 'Linkage',
   '525-a' => 'Supplement note',
   '525-z' => 'Source of note inform.',
   '527-6' => 'Linkage',
   '527-a' => 'Censorship note',
   '530-0' => 'Record control number',
   '530-3' => 'Materials specified',
   '530-5' => 'Institution to which field applies',
   '530-6' => 'Linkage',
   '530-a-auth' => 'Uniform title',
   '530-a-bibl' => 'Add. physical form available note',
   '530-b' => 'Availability source',
   '530-c' => 'Availability conditions',
   '530-d-auth' => 'Date of treaty signing',
   '530-d-bibl' => 'Order number',
   '530-f' => 'Date of a work',
   '530-g' => 'Misc. inform.',
   '530-h' => 'Medium',
   '530-i' => 'Reference instruction phrase',
   '530-k' => 'Form subheading',
   '530-l' => 'Lang. of a work',
   '530-m' => 'Medium of performance for music',
   '530-n' => 'Number of part/section of a work',
   '530-o' => 'Arranged statement for music',
   '530-p' => 'Name of part/section of a work',
   '530-r' => 'Key for music',
   '530-s' => 'Version',
   '530-t' => 'Title of a work',
   '530-v' => 'Form subdivision',
   '530-w' => 'Control subfield',
   '530-x' => 'General subdivision',
   '530-y' => 'Chronological subdivision',
   '530-z-auth' => 'Geographic subdivision',
   '530-z-bibl' => 'Source of note inform.',
   '531-6' => 'Linkage',
   '531-a' => 'Eligibility',
   '531-b' => 'Fee',
   '531-c' => 'Admission procedures',
   '531-d' => 'Documents required',
   '531-e' => 'Waiting list',
   '531-f' => 'Waiting period',
   '533-3' => 'Materials specified',
   '533-6' => 'Linkage',
   '533-7' => 'Fixed-length data elements of reproduction',
   '533-a' => 'Type of reproduction',
   '533-b' => 'Place of reproduction',
   '533-c' => 'Agency responsible for reproduction',
   '533-d' => 'Date of reproduction',
   '533-e' => 'Physical description of reproduction',
   '533-f' => 'Series statement of reproduction',
   '533-m' => 'Dates of publication and/or sequential designation of issues reproduced',
   '533-n' => 'Note about reproduction',
   '534-6' => 'Linkage',
   '534-a' => 'Main entry of original',
   '534-b' => 'Edition statement of original',
   '534-c' => 'Publication, distribution, etc. of original',
   '534-e' => 'Physical description, etc. of original',
   '534-f' => 'Series statement of original',
   '534-k' => 'Key title of original',
   '534-l' => 'Location of original',
   '534-m' => 'Material specific details',
   '534-n' => 'Note about original',
   '534-p' => 'Introductory phrase',
   '534-t' => 'Title statement of original',
   '534-x' => 'ISSN',
   '534-z' => 'ISBN',
   '535-3' => 'Materials specified',
   '535-6' => 'Linkage',
   '535-a' => 'Custodian',
   '535-b' => 'Postal address',
   '535-c' => 'Country',
   '535-d' => 'Telecommunications address',
   '535-g' => 'Repository location code',
   '536-6' => 'Linkage',
   '536-a-bibl' => 'Text of note',
   '536-a-comm' => 'Funding source note',
   '536-b' => 'Contract number',
   '536-c' => 'Grant number',
   '536-d' => 'Undifferentiated number',
   '536-e' => 'Program element number',
   '536-f' => 'Project number',
   '536-g' => 'Task number',
   '536-h' => 'Work unit number',
   '537-6' => 'Linkage',
   '537-a' => 'Source of data note',
   '538-6' => 'Linkage',
   '538-a' => 'System details note',
   '540-3' => 'Materials specified',
   '540-5' => 'Institution to which field applies',
   '540-6' => 'Linkage',
   '540-a' => 'Terms governing use and reproduction',
   '540-b' => 'Jurisdiction',
   '540-c' => 'Authorization',
   '540-d' => 'Auth. users',
   '541-3' => 'Materials specified',
   '541-5' => 'Institution to which field applies',
   '541-6' => 'Linkage',
   '541-a' => 'Source of acquisition',
   '541-b' => 'Address',
   '541-c' => 'Method of acquisition',
   '541-d' => 'Date of acquisition',
   '541-e' => 'Accession number',
   '541-f' => 'Owner',
   '541-h' => 'Purchase price',
   '541-n' => 'Extent',
   '541-o' => 'Type of unit',
   '543-6' => 'Linkage',
   '543-a' => 'Solicitation inform. note',
   '544-3' => 'Materials specified',
   '544-6' => 'Linkage',
   '544-a' => 'Custodian',
   '544-b' => 'Address',
   '544-c' => 'Country',
   '544-d' => 'Title',
   '544-e' => 'Provenance',
   '544-n' => 'Note',
   '545-6' => 'Linkage',
   '545-a' => 'Biographical or historical note',
   '545-b' => 'Expansion of biographical or historical note',
   '546-3' => 'Materials specified',
   '546-6' => 'Linkage',
   '546-a' => 'Lang. note',
   '546-b' => 'Information code or alphabet',
   '546-z' => 'Source of note inform.',
   '547-6' => 'Linkage',
   '547-a' => 'Former title complexity note',
   '547-z' => 'Source of note inform.',
   '550-0' => 'Record control number',
   '550-5' => 'Institution to which field applies',
   '550-6' => 'Linkage',
   '550-a-auth' => 'Topical term or geographic name as entry element',
   '550-a-bibl' => 'Issuing body note',
   '550-b' => 'Topical term following geographic name as entry element',
   '550-i' => 'Reference instruction phrase',
   '550-v' => 'Form subdivision',
   '550-w' => 'Control subfield',
   '550-x' => 'General subdivision',
   '550-y' => 'Chronological subdivision',
   '550-z-auth' => 'Geographic subdivision',
   '550-z-bibl' => 'Source of note inform.',
   '551-0' => 'Record control number',
   '551-5' => 'Institution to which field applies',
   '551-6' => 'Linkage',
   '551-a-auth' => 'Geographic name',
   '551-a-bibl' => 'Entity type label',
   '551-a-comm' => 'Budget note',
   '551-b-auth' => 'Name following place as entry element',
   '551-b-bibl' => 'Entity type definition and source',
   '551-c' => 'Attribute label',
   '551-d' => 'Attribute definition and source',
   '551-e' => 'Enumerated domain value',
   '551-f' => 'Enumerated domain value definition and source',
   '551-g' => 'Range domain minimum and maximum',
   '551-h' => 'Codeset name and source',
   '551-i-auth' => 'Reference instruction phrase',
   '551-i-bibl' => 'Unrepresentable domain',
   '551-j' => 'Attribute units of measurement and resolution',
   '551-k' => 'Beginning date and ending date of attribute values',
   '551-l' => 'Attribute value accuracy',
   '551-m' => 'Attribute value accuracy explanation',
   '551-n' => 'Attribute measurement frequency',
   '551-o' => 'Entity and attribute overview',
   '551-p' => 'Entity and attribute detail citation',
   '551-v' => 'Form subdivision',
   '551-w' => 'Control subfield',
   '551-x' => 'General subdivision',
   '551-y' => 'Chronological subdivision',
   '551-z' => 'Geographic subdivision',
   '553-a' => 'Class. number element--single number or beginning number of span',
   '553-c' => 'Class. number element--ending number of span',
   '553-h' => 'Caption hierarchy',
   '553-i' => 'Reference instruction phrase',
   '553-j' => 'Caption',
   '553-k' => 'Summary number span caption hierarchy',
   '553-t' => 'Topic',
   '553-w' => 'Control subfield',
   '553-y' => 'Table identification--schedule',
   '553-z' => 'Table identification',
   '555-0' => 'Record control number',
   '555-3' => 'Materials specified',
   '555-5' => 'Institution to which field applies',
   '555-6' => 'Linkage',
   '555-a-auth' => 'Genre/form term',
   '555-a-bibl' => 'Cumulative index/finding aids note',
   '555-b' => 'Availability source',
   '555-c' => 'Degree of control',
   '555-d' => 'Bibliographic reference',
   '555-i' => 'Reference instruction phrase',
   '555-v' => 'Form subdivision',
   '555-w' => 'Control subfield',
   '555-x' => 'General subdivision',
   '555-y' => 'Chronological subdivision',
   '555-z' => 'Geographic subdivision',
   '556-6' => 'Linkage',
   '556-a' => 'Information about documentation note',
   '556-z' => 'ISBN',
   '561-3' => 'Materials specified',
   '561-5' => 'Institution to which field applies',
   '561-6' => 'Linkage',
   '561-a' => 'History',
   '561-b' => 'Time of collation',
   '562-3' => 'Materials specified',
   '562-5' => 'Institution to which field applies',
   '562-6' => 'Linkage',
   '562-a' => 'Identifying markings',
   '562-b' => 'Copy identification',
   '562-c' => 'Version identification',
   '562-d' => 'Presentation format',
   '562-e' => 'Number of copies',
   '565-3' => 'Materials specified',
   '565-6' => 'Linkage',
   '565-a' => 'Number of cases/variables',
   '565-b' => 'Name of variable',
   '565-c' => 'Unit of analysis',
   '565-d' => 'Universe of data',
   '565-e' => 'Filing scheme or code',
   '567-6' => 'Linkage',
   '567-a' => 'Methodology note',
   '570-6' => 'Linkage',
   '570-a-bibl' => 'Editor note',
   '570-a-comm' => 'Personnel note',
   '570-b' => 'Election inform.',
   '570-z' => 'Source of note inform.',
   '571-6' => 'Linkage',
   '571-a' => 'Volunteers note',
   '571-b' => 'Special requirements',
   '572-6' => 'Linkage',
   '572-a' => 'Affiliation and other relationships note',
   '573-6' => 'Linkage',
   '573-a' => 'Credentials note',
   '574-6' => 'Linkage',
   '574-a' => 'Transportation and directions note',
   '575-a' => 'Accommodations for the disabled note',
   '576-6' => 'Linkage',
   '576-a' => 'Services available note',
   '580-0' => 'Record control number',
   '580-5' => 'Institution to which field applies',
   '580-6' => 'Linkage',
   '580-a' => 'Linking entry complexity note',
   '580-i' => 'Reference instruction phrase',
   '580-v' => 'Form subdivision',
   '580-w' => 'Control subfield',
   '580-x' => 'General subdivision',
   '580-y' => 'Chronological subdivision',
   '580-z-auth' => 'Geographic subdivision',
   '580-z-bibl' => 'Source of note inform.',
   '581-0' => 'Record control number',
   '581-3' => 'Materials specified',
   '581-5' => 'Institution to which field applies',
   '581-6' => 'Linkage',
   '581-a-bibl' => 'Publications about described materials note',
   '581-a-comm' => 'Publications note',
   '581-i' => 'Reference instruction phrase',
   '581-v' => 'Form subdivision',
   '581-w' => 'Control subfield',
   '581-x' => 'General subdivision',
   '581-y' => 'Chronological subdivision',
   '581-z-auth' => 'Geographic subdivision',
   '581-z-bibl' => 'ISBN',
   '582-0' => 'Record control number',
   '582-5' => 'Institution to which field applies',
   '582-6' => 'Linkage',
   '582-a' => 'Related computer files note',
   '582-i' => 'Reference instruction phrase',
   '582-v' => 'Form subdivision',
   '582-w' => 'Control subfield',
   '582-x' => 'General subdivision',
   '582-y' => 'Chronological subdivision',
   '582-z' => 'Geographic subdivision',
   '583-3' => 'Materials specified',
   '583-5' => 'Institution to which field applies',
   '583-6' => 'Linkage',
   '583-8' => 'Link and sequence number',
   '583-a' => 'Action',
   '583-b' => 'Action identification',
   '583-c' => 'Time of action',
   '583-d' => 'Action interval',
   '583-e' => 'Contingency for action',
   '583-f' => 'Authorization',
   '583-h' => 'Jurisdiction',
   '583-i' => 'Method of action',
   '583-j' => 'Site of action',
   '583-k' => 'Action agent',
   '583-l' => 'Status',
   '583-n' => 'Extent',
   '583-o' => 'Type of unit',
   '583-x' => 'Nonpublic note',
   '583-z' => 'Public note',
   '584-3' => 'Materials specified',
   '584-5' => 'Institution to which field applies',
   '584-6' => 'Linkage',
   '584-a' => 'Accumulation',
   '584-b' => 'Frequency of use',
   '585-0' => 'Record control number',
   '585-3' => 'Materials specified',
   '585-5' => 'Institution to which field applies',
   '585-6' => 'Linkage',
   '585-a' => 'Exhibitions note',
   '585-i' => 'Reference instruction phrase',
   '585-v' => 'Form subdivision',
   '585-w' => 'Control subfield',
   '585-x' => 'General subdivision',
   '585-y' => 'Chronological subdivision',
   '585-z' => 'Geographic subdivision',
   '586-3' => 'Materials specified',
   '586-6' => 'Linkage',
   '586-a' => 'Awards note',
   '587-6' => 'Linkage',
   '587-a' => 'Other inform. available note',
   '590-a' => 'Receipt date',
   '590-b' => 'Provenance',
   '590-d' => 'Origin of safety copy',
   '600-2' => 'Source of heading or term',
   '600-3' => 'Materials specified',
   '600-4' => 'Relator code',
   '600-6' => 'Linkage',
   '600-a' => 'Personal name',
   '600-b' => 'Numeration',
   '600-c' => 'Titles and other words associated with a name',
   '600-d' => 'Dates associated with a name',
   '600-e' => 'Relator term',
   '600-f' => 'Date of a work',
   '600-g' => 'Misc. inform.',
   '600-h' => 'Medium',
   '600-k' => 'Form subheading',
   '600-l' => 'Lang. of a work',
   '600-m' => 'Medium of performance for music',
   '600-n-bibl' => 'Number of part/section of a work',
   '600-n-comm' => 'Number of part/section',
   '600-o' => 'Arranged statement for music',
   '600-p-bibl' => 'Name of part/section of a work',
   '600-p-comm' => 'Name of part/section',
   '600-q' => 'Fuller form of name',
   '600-r' => 'Key for music',
   '600-s' => 'Version',
   '600-t-bibl' => 'Title of a work',
   '600-t-comm' => 'Title',
   '600-u' => 'Affiliation',
   '600-v' => 'Form subdivision',
   '600-x' => 'General subdivision',
   '600-y' => 'Chronological subdivision',
   '600-z' => 'Geographic subdivision',
   '610-2' => 'Source of heading or term',
   '610-3' => 'Materials specified',
   '610-4' => 'Relator code',
   '610-6' => 'Linkage',
   '610-a' => 'Corporate name or jurisdiction name as entry element',
   '610-b' => 'Subordinate unit',
   '610-c' => 'Location of meeting',
   '610-d-bibl' => 'Date of meeting or treaty signing',
   '610-d-comm' => 'Date of meeting',
   '610-e' => 'Relator term',
   '610-f' => 'Date of a work',
   '610-g' => 'Misc. inform.',
   '610-h' => 'Medium',
   '610-k' => 'Form subheading',
   '610-l' => 'Lang. of a work',
   '610-m' => 'Medium of performance for music',
   '610-n' => 'Number of part/section/meeting',
   '610-o' => 'Arranged statement for music',
   '610-p-bibl' => 'Name of part/section of a work',
   '610-p-comm' => 'Name of part/section',
   '610-r' => 'Key for music',
   '610-s' => 'Version',
   '610-t-bibl' => 'Title of a work',
   '610-t-comm' => 'Title',
   '610-u' => 'Affiliation',
   '610-v' => 'Form subdivision',
   '610-x' => 'General subdivision',
   '610-y' => 'Chronological subdivision',
   '610-z' => 'Geographic subdivision',
   '611-2' => 'Source of heading or term',
   '611-3' => 'Materials specified',
   '611-4' => 'Relator code',
   '611-6' => 'Linkage',
   '611-a' => 'Meeting name or jurisdiction name as entry element',
   '611-b' => 'Number',
   '611-c' => 'Location of meeting',
   '611-d' => 'Date of meeting',
   '611-e' => 'Subordinate unit',
   '611-f' => 'Date of a work',
   '611-g' => 'Misc. inform.',
   '611-h' => 'Medium',
   '611-k' => 'Form subheading',
   '611-l' => 'Lang. of a work',
   '611-n' => 'Number of part/section/meeting',
   '611-p-bibl' => 'Name of part/section of a work',
   '611-p-comm' => 'Name of part/section',
   '611-q' => 'Name of meeting following jurisdiction name entry element',
   '611-s' => 'Version',
   '611-t-bibl' => 'Title of a work',
   '611-t-comm' => 'Title',
   '611-u' => 'Affiliation',
   '611-v' => 'Form subdivision',
   '611-x' => 'General subdivision',
   '611-y' => 'Chronological subdivision',
   '611-z' => 'Geographic subdivision',
   '630-2' => 'Source of heading or term',
   '630-3' => 'Materials specified',
   '630-6' => 'Linkage',
   '630-a-bibl' => 'Uniform title',
   '630-a-comm' => 'Title',
   '630-d' => 'Date of treaty signing',
   '630-f' => 'Date of a work',
   '630-g' => 'Misc. inform.',
   '630-h' => 'Medium',
   '630-k' => 'Form subheading',
   '630-l' => 'Lang. of a work',
   '630-m' => 'Medium of performance for music',
   '630-n' => 'Number of part/section of a work',
   '630-o' => 'Arranged statement for music',
   '630-p' => 'Name of part/section of a work',
   '630-r' => 'Key for music',
   '630-s' => 'Version',
   '630-t' => 'Title of a work',
   '630-v' => 'Form subdivision',
   '630-x' => 'General subdivision',
   '630-y' => 'Chronological subdivision',
   '630-z' => 'Geographic subdivision',
   '640-6' => 'Linkage',
   '640-a' => 'Dates of publication and/or volume designation',
   '640-z' => 'Source of inform.',
   '641-6' => 'Linkage',
   '641-a' => 'Numbering peculiarities note',
   '641-z' => 'Source of inform.',
   '642-5' => 'Institution/copy to which field applies',
   '642-6' => 'Linkage',
   '642-a' => 'Series numbering example',
   '642-d' => 'Volumes/dates to which series numbering example applies',
   '643-6' => 'Linkage',
   '643-a' => 'Place',
   '643-b' => 'Publisher/issuing body',
   '643-d' => 'Volumes/dates to which place and publisher/issuing body apply',
   '644-5' => 'Institution/copy to which field applies',
   '644-6' => 'Linkage',
   '644-a' => 'Series analysis practice',
   '644-b' => 'Exceptions to analysis practice',
   '644-d' => 'Volumes/dates to which analysis practice applies',
   '645-5' => 'Institution/copy to which field applies',
   '645-6' => 'Linkage',
   '645-a' => 'Series tracing practice',
   '645-d' => 'Volumes/dates to which tracing practice applies',
   '646-5' => 'Institution/copy to which field applies',
   '646-6' => 'Linkage',
   '646-a' => 'Series class. practice',
   '646-d' => 'Volumes/dates to which class. practice applies',
   '650-2' => 'Source of heading or term',
   '650-3' => 'Materials specified',
   '650-6' => 'Linkage',
   '650-a' => 'Topical term or geographic name as entry element',
   '650-b' => 'Topical term following geographic name as entry element',
   '650-c' => 'Location of event',
   '650-d' => 'Active dates',
   '650-e' => 'Relator term',
   '650-v' => 'Form subdivision',
   '650-x' => 'General subdivision',
   '650-y' => 'Chronological subdivision',
   '650-z' => 'Geographic subdivision',
   '651-2' => 'Source of heading or term',
   '651-3' => 'Materials specified',
   '651-6' => 'Linkage',
   '651-a' => 'Geographic name',
   '651-b' => 'Geographic name following place entry element',
   '651-v' => 'Form subdivision',
   '651-x' => 'General subdivision',
   '651-y' => 'Chronological subdivision',
   '651-z' => 'Geographic subdivision',
   '652-a' => 'Geographic name of place element',
   '652-x' => 'General subdivision',
   '652-y' => 'Chronological subdivision',
   '652-z' => 'Geographic subdivision',
   '653-6' => 'Linkage',
   '653-a' => 'Uncontrolled term',
   '654-2' => 'Source of heading or term',
   '654-3-bibl' => 'Material specified',
   '654-3-comm' => 'Materials specified',
   '654-a' => 'Focus term',
   '654-b' => 'Non-focus term',
   '654-c' => 'Facet/hierarchy designation',
   '654-v' => 'Form subdivision',
   '654-x' => 'General subdivision',
   '654-y' => 'Chronological subdivision',
   '654-z' => 'Geographic subdivision',
   '655-2' => 'Source of term',
   '655-3' => 'Materials specified',
   '655-5' => 'Institution to which field applies',
   '655-6' => 'Linkage',
   '655-a' => 'Genre/form',
   '655-b' => 'Non-focus term',
   '655-c' => 'Facet/hierarchy designation',
   '655-v' => 'Form subdivision',
   '655-x' => 'General subdivision',
   '655-y' => 'Chronological subdivision',
   '655-z' => 'Geographic subdivision',
   '656-2' => 'Source of term',
   '656-3' => 'Materials specified',
   '656-6' => 'Linkage',
   '656-a' => 'Occupation',
   '656-k' => 'Form',
   '656-v' => 'Form subdivision',
   '656-x' => 'General subdivision',
   '656-y' => 'Chronological subdivision',
   '656-z' => 'Geographic subdivision',
   '657-2' => 'Source of term',
   '657-3' => 'Materials specified',
   '657-6' => 'Linkage',
   '657-a' => 'Function',
   '657-v' => 'Form subdivision',
   '657-x' => 'General subdivision',
   '657-y' => 'Chronological subdivision',
   '657-z' => 'Geographic subdivision',
   '658-2' => 'Source of term',
   '658-6' => 'Linkage',
   '658-a' => 'Main curriculum objective',
   '658-b' => 'Subordinate curriculum objective',
   '658-c' => 'Curriculum code',
   '658-d' => 'Correlation factor',
   '663-6' => 'Linkage',
   '663-a' => 'Explanatory text',
   '663-b' => 'Heading referred to',
   '663-t' => 'Title referred to',
   '664-6' => 'Linkage',
   '664-a' => 'Explanatory text',
   '664-b' => 'Heading referred to',
   '664-t' => 'Title referred to',
   '665-6' => 'Linkage',
   '665-a' => 'History reference',
   '666-6' => 'Linkage',
   '666-a' => 'General explanatory reference',
   '667-5' => 'Institution to which field applies',
   '667-6' => 'Linkage',
   '667-a' => 'Nonpublic general note',
   '668-a' => 'Characters in nonroman alphabet',
   '670-6' => 'Linkage',
   '670-a' => 'Source citation',
   '670-b' => 'Information found',
   '675-6' => 'Linkage',
   '675-a' => 'Source citation',
   '678-6' => 'Linkage',
   '678-a' => 'Biographical or historical data',
   '678-b' => 'Expansion',
   '680-5' => 'Institution to which field applies',
   '680-6' => 'Linkage',
   '680-8' => 'Link and sequence number',
   '680-a-auth' => 'Heading or subdivision term',
   '680-a-clas' => 'Class. number--single number or beginning number of span',
   '680-c' => 'Class. number--ending number of span',
   '680-i' => 'Explanatory text',
   '680-y' => 'Table identification--schedule',
   '680-z' => 'Table identification',
   '681-6' => 'Linkage',
   '681-a-auth' => 'Subject heading or subdivision term',
   '681-a-clas' => 'Class. number--single number or beginning number of span',
   '681-c' => 'Class. number--ending number of span',
   '681-i' => 'Explanatory text',
   '681-y' => 'Table identification--schedule',
   '681-z' => 'Table identification',
   '682-6' => 'Linkage',
   '682-a' => 'Replacement heading',
   '682-i' => 'Explanatory text',
   '683-5' => 'Institution to which field applies',
   '683-8' => 'Link and sequence number',
   '683-a' => 'Class. number--single number or beginning number of span',
   '683-c' => 'Class. number--ending number of span',
   '683-i' => 'Explanatory text',
   '683-p' => 'Corresponding class. field',
   '683-y' => 'Table identification--schedule',
   '683-z' => 'Table identification',
   '684-5' => 'Institution to which field applies',
   '684-8' => 'Link and sequence number',
   '684-a' => 'Class. number--single number or beginning number of span',
   '684-c' => 'Class. number--ending number of span',
   '684-i' => 'Explanatory text',
   '684-j' => 'Caption',
   '684-y' => 'Table identification--schedule',
   '684-z' => 'Table identification',
   '685-2' => 'Edition number',
   '685-5' => 'Institution to which field applies',
   '685-8' => 'Link and sequence number',
   '685-a' => 'New number--single number or beginning number of span',
   '685-b' => 'Previous number--single number or beginning number of span',
   '685-c' => 'Class. number--ending number of span',
   '685-d' => 'Date of implementation of authoritative agency',
   '685-e' => 'Local implementation date',
   '685-f' => 'Title and publication date',
   '685-i' => 'Explanatory text',
   '685-t' => 'Topic',
   '685-y' => 'Table identification--schedule',
   '685-z' => 'Table identification',
   '688-5' => 'Institution to which field applies',
   '688-6' => 'Linkage',
   '688-a' => 'Application history note',
   '700-0' => 'Record control number',
   '700-2' => 'Source of heading or term',
   '700-3' => 'Materials specified',
   '700-4' => 'Relator code',
   '700-5' => 'Institution to which field applies',
   '700-6' => 'Linkage',
   '700-8' => 'Linking number',
   '700-a' => 'Personal name',
   '700-b' => 'Numeration',
   '700-c' => 'Titles and other words associated with a name',
   '700-d' => 'Dates associated with a name',
   '700-e' => 'Relator term',
   '700-f' => 'Date of a work',
   '700-g' => 'Misc. inform.',
   '700-h' => 'Medium',
   '700-i' => 'Explanatory text',
   '700-k' => 'Form subheading',
   '700-l' => 'Lang. of a work',
   '700-m' => 'Medium of performance for music',
   '700-n-auth' => 'Number of part/section of a work',
   '700-n-bibl' => 'Number of part/section of a work',
   '700-n-clas' => 'Number of part/section of a work',
   '700-n-comm' => 'Number of part/section',
   '700-o' => 'Arranged statement for music',
   '700-p-auth' => 'Name of part/section of a work',
   '700-p-bibl' => 'Name of part/section of a work',
   '700-p-clas' => 'Name of part/section of a work',
   '700-p-comm' => 'Name of part/section',
   '700-q' => 'Fuller form of name',
   '700-r' => 'Key for music',
   '700-s' => 'Version',
   '700-t-auth' => 'Title of a work',
   '700-t-bibl' => 'Title of a work',
   '700-t-clas' => 'Title of a work',
   '700-t-comm' => 'Title',
   '700-u' => 'Affiliation',
   '700-v' => 'Form subdivision',
   '700-w-auth' => 'Control subfield',
   '700-w-clas' => 'Authority record control number',
   '700-w-comm' => 'Record control number',
   '700-x-auth' => 'General subdivision',
   '700-x-bibl' => 'ISSN',
   '700-x-clas' => 'General subdivision',
   '700-y' => 'Chronological subdivision',
   '700-z' => 'Geographic subdivision',
   '705-a' => 'Personal name',
   '705-b' => 'Numeration',
   '705-c' => 'Titles and other words associated with a name',
   '705-d' => 'Dates associated with a name',
   '705-e' => 'Relator term',
   '705-f' => 'Date of a work',
   '705-g' => 'Misc. inform.',
   '705-h' => 'Medium',
   '705-k' => 'Form subheading',
   '705-l' => 'Lang. of a work',
   '705-m' => 'Medium of performance for music',
   '705-n' => 'Number of part/section of a work',
   '705-o' => 'Arranged statement for music',
   '705-p' => 'Name of part/section of a work',
   '705-r' => 'Key for music',
   '705-s' => 'Version',
   '705-t' => 'Title of a work',
   '710-0' => 'Record control number',
   '710-2' => 'Source of heading or term',
   '710-3' => 'Materials specified',
   '710-4' => 'Relator code',
   '710-5' => 'Institution to which field applies',
   '710-6' => 'Linkage',
   '710-8' => 'Linking number',
   '710-a' => 'Corporate name or jurisdiction name as entry element',
   '710-b' => 'Subordinate unit',
   '710-c' => 'Location of meeting',
   '710-d-auth' => 'Date of meeting or treaty signing',
   '710-d-bibl' => 'Date of meeting or treaty signing',
   '710-d-clas' => 'Date of meeting or treaty signing',
   '710-d-comm' => 'Date of meeting',
   '710-e' => 'Relator term',
   '710-f' => 'Date of a work',
   '710-g' => 'Misc. inform.',
   '710-h' => 'Medium',
   '710-i' => 'Explanatory text',
   '710-k' => 'Form subheading',
   '710-l' => 'Lang. of a work',
   '710-m' => 'Medium of performance for music',
   '710-n' => 'Number of part/section/meeting',
   '710-o' => 'Arranged statement for music',
   '710-p-auth' => 'Name of part/section of a work',
   '710-p-bibl' => 'Name of part/section of a work',
   '710-p-clas' => 'Name of part/section of a work',
   '710-p-comm' => 'Name of part/section',
   '710-r' => 'Key for music',
   '710-s' => 'Version',
   '710-t-auth' => 'Title of a work',
   '710-t-bibl' => 'Title of a work',
   '710-t-clas' => 'Title of a work',
   '710-t-comm' => 'Title',
   '710-u' => 'Affiliation',
   '710-v' => 'Form subdivision',
   '710-w-auth' => 'Control subfield',
   '710-w-clas' => 'Authority record control number',
   '710-w-comm' => 'Record control number',
   '710-x-auth' => 'General subdivision',
   '710-x-bibl' => 'ISSN',
   '710-x-clas' => 'General subdivision',
   '710-y' => 'Chronological subdivision',
   '710-z' => 'Geographic subdivision',
   '711-0' => 'Record control number',
   '711-1' => 'Lang. of a work',
   '711-2' => 'Source of heading or term',
   '711-3' => 'Materials specified',
   '711-4' => 'Relator code',
   '711-5' => 'Institution to which field applies',
   '711-6' => 'Linkage',
   '711-8' => 'Linking number',
   '711-a' => 'Meeting name or jurisdiction name as entry element',
   '711-b' => 'Number',
   '711-c' => 'Location of meeting',
   '711-d' => 'Date of meeting',
   '711-e' => 'Subordinate unit',
   '711-f' => 'Date of a work',
   '711-g' => 'Misc. inform.',
   '711-h' => 'Medium',
   '711-i' => 'Explanatory text',
   '711-k' => 'Form subheading',
   '711-l' => 'Lang. of a work',
   '711-n' => 'Number of part/section/meeting',
   '711-p-auth' => 'Name of part/section of a work',
   '711-p-bibl' => 'Name of part/section of a work',
   '711-p-clas' => 'Name of part/section of a work',
   '711-p-comm' => 'Name of part/section',
   '711-q' => 'Name of meeting following jurisdiction name entry element',
   '711-s' => 'Version',
   '711-t-auth' => 'Title of a work',
   '711-t-bibl' => 'Title of a work',
   '711-t-clas' => 'Title of a work',
   '711-t-comm' => 'Title',
   '711-u' => 'Affiliation',
   '711-v' => 'Form subdivision',
   '711-w-auth' => 'Control subfield',
   '711-w-clas' => 'Authority record control number',
   '711-w-comm' => 'Record control number',
   '711-x-auth' => 'General subdivision',
   '711-x-bibl' => 'ISSN',
   '711-x-clas' => 'General subdivision',
   '711-y' => 'Chronological subdivision',
   '711-z' => 'Geographic subdivision',
   '715-a' => 'Corporate name or jurisdiction name',
   '715-b' => 'Subordinate unit',
   '715-e' => 'Relator term',
   '715-f' => 'Date of a work',
   '715-g' => 'Misc. inform.',
   '715-h' => 'Medium',
   '715-k' => 'Form subheading',
   '715-l' => 'Lang. of a work',
   '715-m' => 'Medium of performance for music',
   '715-n' => 'Number of part/section/meeting',
   '715-o' => 'Arranged statement for music',
   '715-p' => 'Name of part/section of a work',
   '715-r' => 'Key for music',
   '715-s' => 'Version',
   '715-t' => 'Title of a work',
   '715-u' => 'Nonprinting inform.',
   '720-4' => 'Relator code',
   '720-6' => 'Linkage',
   '720-a' => 'Name',
   '720-e' => 'Relator term',
   '730-0' => 'Record control number',
   '730-1' => 'Lang. of a work',
   '730-2' => 'Source of heading or term',
   '730-3' => 'Materials specified',
   '730-5' => 'Institution to which field applies',
   '730-6' => 'Linkage',
   '730-8' => 'Linking number',
   '730-a-auth' => 'Uniform title',
   '730-a-bibl' => 'Uniform title',
   '730-a-clas' => 'Uniform title',
   '730-a-comm' => 'Title',
   '730-d' => 'Date of treaty signing',
   '730-f' => 'Date of a work',
   '730-g' => 'Misc. inform.',
   '730-h' => 'Medium',
   '730-i' => 'Explanatory text',
   '730-k' => 'Form subheading',
   '730-l' => 'Lang. of a work',
   '730-m' => 'Medium of performance for music',
   '730-n' => 'Number of part/section of a work',
   '730-o' => 'Arranged statement for music',
   '730-p' => 'Name of part/section of a work',
   '730-r' => 'Key for music',
   '730-s' => 'Version',
   '730-t' => 'Title of a work',
   '730-v' => 'Form subdivision',
   '730-w-auth' => 'Control subfield',
   '730-w-clas' => 'Authority record control number',
   '730-w-comm' => 'Record control number',
   '730-x-auth' => 'General subdivision',
   '730-x-bibl' => 'ISSN',
   '730-x-clas' => 'General subdivision',
   '730-y' => 'Chronological subdivision',
   '730-z' => 'Geographic subdivision',
   '740-5' => 'Institution to which field applies',
   '740-6' => 'Linkage',
   '740-a-bibl' => 'Uncontrolled related/analytical title',
   '740-a-comm' => 'Title',
   '740-h' => 'Medium',
   '740-n-bibl' => 'Number of part/section of a work',
   '740-n-comm' => 'Number of part/section',
   '740-p-bibl' => 'Name of part/section of a work',
   '740-p-comm' => 'Name of part/section',
   '750-0' => 'Record control number',
   '750-2' => 'Source of heading or term',
   '750-3' => 'Materials specified',
   '750-5' => 'Institution to which field applies',
   '750-6' => 'Linkage',
   '750-8' => 'Linking number',
   '750-a' => 'Topical term or geographic name as entry element',
   '750-b' => 'Topical term following geographic name as entry element',
   '750-c' => 'Location of event',
   '750-d' => 'Active dates',
   '750-i' => 'Explanatory text',
   '750-v' => 'Form subdivision',
   '750-w-auth' => 'Control subfield',
   '750-w-clas' => 'Authority record control number',
   '750-x' => 'General subdivision',
   '750-y' => 'Chronological subdivision',
   '750-z' => 'Geographic subdivision',
   '751-0' => 'Record control number',
   '751-2' => 'Source of heading or term',
   '751-3' => 'Materials specified',
   '751-5' => 'Institution to which field applies',
   '751-6' => 'Linkage',
   '751-8' => 'Linking number',
   '751-a' => 'Geographic name',
   '751-i' => 'Explanatory text',
   '751-v' => 'Form subdivision',
   '751-w-auth' => 'Control subfield',
   '751-w-clas' => 'Authority record control number',
   '751-x' => 'General subdivision',
   '751-y' => 'Chronological subdivision',
   '751-z' => 'Geographic subdivision',
   '752-6' => 'Linkage',
   '752-a' => 'Country',
   '752-b' => 'State, province, territory',
   '752-c' => 'County, region, islands area',
   '752-d' => 'City',
   '753-6' => 'Linkage',
   '753-a-bibl' => 'Make and model of machine',
   '753-a-clas' => 'Index term',
   '753-b-bibl' => 'Programming language',
   '753-b-clas' => 'Index term--succeeding level',
   '753-c' => 'Operating system',
   '753-d' => 'Index term referred from',
   '753-e' => 'Example class number',
   '753-i' => 'Explanatory text',
   '753-s' => 'See also reference term',
   '753-t' => 'See also reference term--succeeding level',
   '753-u' => 'Use reference term',
   '753-v' => 'Use reference term--succeeding level',
   '754-2-bibl' => 'Source of taxonomic identification',
   '754-2-clas' => 'Source of heading or term',
   '754-3' => 'Material specified',
   '754-6' => 'Linkage',
   '754-a-bibl' => 'Taxonomic name/taxonomic hierarchical category',
   '754-a-clas' => 'Focus term',
   '754-b' => 'Term',
   '754-c' => 'Facet/hierarchy designation',
   '754-v' => 'Form subdivision',
   '754-y' => 'Chronological subdivision',
   '754-z' => 'Geographic subdivision',
   '755-0' => 'Record control number',
   '755-2-auth' => 'Source of heading or term',
   '755-2-bibl' => 'Source of term',
   '755-3' => 'Materials specified',
   '755-5' => 'Institution to which field applies',
   '755-6' => 'Linkage',
   '755-8' => 'Linking number',
   '755-a-auth' => 'Genre/form term as entry element',
   '755-a-bibl' => 'Access term',
   '755-v' => 'Form subdivision',
   '755-w' => 'Control subfield',
   '755-x' => 'General subdivision',
   '755-y' => 'Chronological subdivision',
   '755-z' => 'Geographic subdivision',
   '760-6' => 'Linkage',
   '760-7' => 'Control subfield',
   '760-a' => 'Main entry heading',
   '760-b' => 'Edition',
   '760-c' => 'Qualifying inform.',
   '760-d' => 'Place, publisher, and date of publication',
   '760-g' => 'Relationship inform.',
   '760-h' => 'Physical description',
   '760-i' => 'Display text',
   '760-m' => 'Material-specific details',
   '760-n' => 'Note',
   '760-o' => 'Other item identifier',
   '760-q' => 'Parallel title',
   '760-s' => 'Uniform title',
   '760-t' => 'Title',
   '760-w' => 'Record control number',
   '760-x' => 'ISSN',
   '760-y' => 'CODEN designation',
   '761-8' => 'Link and sequence number',
   '761-a' => 'Number where instructions are found--single number or beginnning number of span',
   '761-b' => 'Base number',
   '761-c' => 'Class. number--ending number of span',
   '761-d' => 'Divided like number',
   '761-e' => 'Example class number',
   '761-f' => 'Facet designator',
   '761-i' => 'Explanatory text',
   '761-n' => 'Negative example class number',
   '761-r' => 'Root number',
   '761-x' => 'Other class. number',
   '761-y' => 'Table identification--schedule',
   '761-z' => 'Table identification',
   '762-6' => 'Linkage',
   '762-7' => 'Control subfield',
   '762-a' => 'Main entry heading',
   '762-b' => 'Edition',
   '762-c' => 'Qualifying inform.',
   '762-d' => 'Place, publisher, and date of publication',
   '762-g' => 'Relationship inform.',
   '762-h' => 'Physical description',
   '762-i-bibl' => 'Display text',
   '762-i-clas' => 'Explanatory text',
   '762-m' => 'Material-specific details',
   '762-n' => 'Note',
   '762-o' => 'Other item identifier',
   '762-q' => 'Parallel title',
   '762-s' => 'Uniform title',
   '762-t' => 'Title',
   '762-w' => 'Record control number',
   '762-x' => 'ISSN',
   '762-y-bibl' => 'CODEN designation',
   '762-y-clas' => 'Schedule',
   '762-z' => 'Table number',
   '763-8' => 'Link and sequence number',
   '763-a' => 'Class. number element--single number or beginning number of span',
   '763-b' => 'Base number',
   '763-c' => 'Class. number element--ending number of span',
   '763-d' => 'Divided like number',
   '763-e' => 'Example class number',
   '763-h' => 'Caption hierarchy',
   '763-i' => 'Explanatory text',
   '763-j' => 'Caption',
   '763-k' => 'Summary number span caption hierarchy',
   '763-m' => 'Manual note',
   '763-n' => 'Number where instructions are found',
   '763-p' => 'Corresponding class. field',
   '763-r' => 'Root number',
   '763-s' => 'See reference',
   '763-x' => 'Other class. number',
   '763-y' => 'Type of division',
   '763-z' => 'Table identification',
   '765-6' => 'Linkage',
   '765-7' => 'Control subfield',
   '765-a-bibl' => 'Main entry heading',
   '765-a-clas' => 'Number where instructions are found--single number or beginning number of span',
   '765-b-bibl' => 'Edition',
   '765-b-clas' => 'Base number',
   '765-c-bibl' => 'Qualifying inform.',
   '765-c-clas' => 'Number where instructions are found--ending number of span',
   '765-d' => 'Place, publisher, and date of publication',
   '765-f' => 'Facet designator',
   '765-g' => 'Relationship inform.',
   '765-h' => 'Physical description',
   '765-i' => 'Display text',
   '765-k' => 'Series data for related item',
   '765-m' => 'Material-specific details',
   '765-n' => 'Note',
   '765-o' => 'Other item identifier',
   '765-q' => 'Parallel title',
   '765-r-bibl' => 'Report number',
   '765-r-clas' => 'Root number',
   '765-s-bibl' => 'Uniform title',
   '765-s-clas' => 'Digits added from class. number in schedule or external table',
   '765-t-bibl' => 'Title',
   '765-t-clas' => 'Digits added from internal subarrangement or add table',
   '765-u-bibl' => 'Std. Techn. Report Number',
   '765-u-clas' => 'Number being analyzed',
   '765-v' => 'Number in internal subarrangement or add table where instructions are found',
   '765-w-bibl' => 'Record control number',
   '765-w-clas' => 'Table identification--internal subarrangement or add table',
   '765-x' => 'ISSN',
   '765-y-bibl' => 'CODEN designation',
   '765-y-clas' => 'Table identification--schedule',
   '765-z-bibl' => 'ISBN',
   '765-z-clas' => 'Table identification',
   '767-6' => 'Linkage',
   '767-7' => 'Control subfield',
   '767-a' => 'Main entry heading',
   '767-b' => 'Edition',
   '767-c' => 'Qualifying inform.',
   '767-d' => 'Place, publisher, and date of publication',
   '767-g' => 'Relationship inform.',
   '767-h' => 'Physical description',
   '767-i' => 'Display text',
   '767-k' => 'Series data for related item',
   '767-m' => 'Material-specific details',
   '767-n' => 'Note',
   '767-o' => 'Other item identifier',
   '767-q' => 'Parallel title',
   '767-r' => 'Report number',
   '767-s' => 'Uniform title',
   '767-t' => 'Title',
   '767-u' => 'Std. Techn. Report Number',
   '767-w' => 'Record control number',
   '767-x' => 'ISSN',
   '767-y' => 'CODEN designation',
   '767-z' => 'ISBN',
   '768-8' => 'Link and sequence number',
   '768-a' => 'Class. number--single number or beginning number of span',
   '768-c' => 'Class. number--ending number of span',
   '768-e' => 'Example class number',
   '768-i' => 'Explanatory text',
   '768-j' => 'Caption',
   '768-n' => 'Negative example class number',
   '768-t' => 'Topic used as example of citation and precedence order instruction',
   '768-x' => 'Exception to table of precedence',
   '768-z' => 'Table identification',
   '770-6' => 'Linkage',
   '770-7' => 'Control subfield',
   '770-a' => 'Main entry heading',
   '770-b' => 'Edition',
   '770-c' => 'Qualifying inform.',
   '770-d' => 'Place, publisher, and date of publication',
   '770-g' => 'Relationship inform.',
   '770-h' => 'Physical description',
   '770-i' => 'Display text',
   '770-k' => 'Series data for related item',
   '770-m' => 'Material-specific details',
   '770-n' => 'Note',
   '770-o' => 'Other item identifier',
   '770-q' => 'Parallel title',
   '770-r' => 'Report number',
   '770-s' => 'Uniform title',
   '770-t' => 'Title',
   '770-u' => 'Std. Techn. Report Number',
   '770-w' => 'Record control number',
   '770-x' => 'ISSN',
   '770-y' => 'CODEN designation',
   '770-z' => 'ISBN',
   '772-6' => 'Linkage',
   '772-7' => 'Control subfield',
   '772-a' => 'Main entry heading',
   '772-b' => 'Edition',
   '772-c' => 'Qualifying inform.',
   '772-d' => 'Place, publisher, and date of publication',
   '772-g' => 'Relationship inform.',
   '772-h' => 'Physical description',
   '772-i' => 'Display text',
   '772-k' => 'Series data for related item',
   '772-m' => 'Material-specific details',
   '772-n' => 'Note',
   '772-o' => 'Other item identifier',
   '772-q' => 'Parallel title',
   '772-r' => 'Report number',
   '772-s' => 'Uniform title',
   '772-t' => 'Title',
   '772-u' => 'Std. Techn. Report Number',
   '772-w' => 'Record control number',
   '772-x' => 'ISSN',
   '772-y' => 'CODEN designation',
   '772-z' => 'ISBN',
   '773-3' => 'Materials specified',
   '773-6' => 'Linkage',
   '773-7' => 'Control subfield',
   '773-a' => 'Main entry heading',
   '773-b' => 'Edition',
   '773-d' => 'Place, publisher, and date of publication',
   '773-g' => 'Relationship inform.',
   '773-h' => 'Physical description',
   '773-i' => 'Display text',
   '773-k' => 'Series data for related item',
   '773-m' => 'Material-specific details',
   '773-n' => 'Note',
   '773-o' => 'Other item identifier',
   '773-p' => 'Abbreviated title',
   '773-r' => 'Report number',
   '773-s' => 'Uniform title',
   '773-t' => 'Title',
   '773-u' => 'Std. Techn. Report Number',
   '773-w' => 'Record control number',
   '773-x' => 'ISSN',
   '773-y' => 'CODEN designation',
   '773-z' => 'ISBN',
   '774-6' => 'Linkage',
   '774-7' => 'Control subfield',
   '774-a' => 'Main entry heading',
   '774-b' => 'Edition',
   '774-c' => 'Qualifying inform.',
   '774-d' => 'Place, publisher, and date of publication',
   '774-g' => 'Relationship inform.',
   '774-h' => 'Physical description',
   '774-i' => 'Display text',
   '774-k' => 'Series data for related item',
   '774-m' => 'Material-specific details',
   '774-n' => 'Note',
   '774-o' => 'Other item identifier',
   '774-r' => 'Report number',
   '774-s' => 'Uniform title',
   '774-t' => 'Title',
   '774-u' => 'Std. Techn. Report Number',
   '774-w' => 'Record control number',
   '774-x' => 'ISSN',
   '774-y' => 'CODEN designation',
   '774-z' => 'ISBN',
   '775-6' => 'Linkage',
   '775-7' => 'Control subfield',
   '775-a' => 'Main entry heading',
   '775-b' => 'Edition',
   '775-c' => 'Qualifying inform.',
   '775-d' => 'Place, publisher, and date of publication',
   '775-e' => 'Lang. code',
   '775-f' => 'Country code',
   '775-g' => 'Relationship inform.',
   '775-h' => 'Physical description',
   '775-k' => 'Series data for related item',
   '775-m' => 'Material-specific details',
   '775-n' => 'Note',
   '775-o' => 'Other item identifier',
   '775-q' => 'Parallel title',
   '775-r' => 'Report number',
   '775-s' => 'Uniform title',
   '775-t' => 'Title',
   '775-u' => 'Std. Techn. Report Number',
   '775-w' => 'Record control number',
   '775-x' => 'ISSN',
   '775-y' => 'CODEN designation',
   '775-z' => 'ISBN',
   '776-6' => 'Linkage',
   '776-7' => 'Control subfield',
   '776-a' => 'Main entry heading',
   '776-b' => 'Edition',
   '776-c' => 'Qualifying inform.',
   '776-d' => 'Place, publisher, and date of publication',
   '776-g' => 'Relationship inform.',
   '776-h' => 'Physical description of source',
   '776-i' => 'Display text',
   '776-k' => 'Series data for related item',
   '776-m' => 'Material-specific details',
   '776-n' => 'Note',
   '776-o' => 'Other item identifier',
   '776-q' => 'Parallel title',
   '776-r' => 'Report number',
   '776-s' => 'Uniform title',
   '776-t' => 'Title',
   '776-u' => 'Std. Techn. Report Number',
   '776-w' => 'Record control number',
   '776-x' => 'ISSN',
   '776-y' => 'CODEN designation',
   '776-z' => 'ISBN',
   '777-6' => 'Linkage',
   '777-7' => 'Control subfield',
   '777-a' => 'Main entry heading',
   '777-b' => 'Edition',
   '777-c' => 'Qualifying inform.',
   '777-d' => 'Place, publisher, and date of publication',
   '777-g' => 'Relationship inform.',
   '777-h' => 'Physical description',
   '777-i' => 'Display text',
   '777-k' => 'Series data for related item',
   '777-m' => 'Material-specific details',
   '777-n' => 'Note',
   '777-o' => 'Other item identifier',
   '777-q' => 'Parallel title',
   '777-s' => 'Uniform title',
   '777-t' => 'Title',
   '777-w' => 'Record control number',
   '777-x' => 'ISSN',
   '777-y' => 'CODEN designation',
   '780-0' => 'Record control number',
   '780-2' => 'Source of heading or term',
   '780-5' => 'Institution to which field applies',
   '780-6' => 'Linkage',
   '780-7' => 'Control subfield',
   '780-8' => 'Linking number',
   '780-a' => 'Main entry heading',
   '780-b' => 'Edition',
   '780-c' => 'Qualifying inform.',
   '780-d' => 'Place, publisher, and date of publication',
   '780-g' => 'Relationship inform.',
   '780-h' => 'Physical description',
   '780-i' => 'Display text',
   '780-k' => 'Series data for related item',
   '780-m' => 'Material-specific details',
   '780-n' => 'Note',
   '780-o' => 'Other item identifier',
   '780-q' => 'Parallel title',
   '780-r' => 'Report number',
   '780-s' => 'Uniform title',
   '780-t' => 'Title',
   '780-u' => 'Std. Techn. Report Number',
   '780-v' => 'Form subdivision',
   '780-w-auth' => 'Control subfield',
   '780-w-bibl' => 'Record control number',
   '780-x-auth' => 'General subdivision',
   '780-x-bibl' => 'ISSN',
   '780-y-auth' => 'Chronological subdivision',
   '780-y-bibl' => 'CODEN designation',
   '780-z-auth' => 'Geographic subdivision',
   '780-z-bibl' => 'ISBN',
   '781-0' => 'Record control number',
   '781-2' => 'Source of heading or term',
   '781-5' => 'Institution to which field applies',
   '781-6' => 'Linkage',
   '781-8' => 'Linking number',
   '781-v' => 'Form subdivision',
   '781-w' => 'Control subfield',
   '781-x' => 'General subdivision',
   '781-y' => 'Chronological subdivision',
   '781-z' => 'Geographic subdivision',
   '782-0' => 'Record control number',
   '782-2' => 'Source of heading or term',
   '782-5' => 'Institution to which field applies',
   '782-6' => 'Linkage',
   '782-8' => 'Linking number',
   '782-v' => 'Form subdivision',
   '782-w' => 'Control subfield',
   '782-x' => 'General subdivision',
   '782-y' => 'Chronological subdivision',
   '782-z' => 'Geographic subdivision',
   '785-0' => 'Record control number',
   '785-2' => 'Source of heading or term',
   '785-5' => 'Institution to which field applies',
   '785-6' => 'Linkage',
   '785-7' => 'Control subfield',
   '785-8' => 'Linking number',
   '785-a' => 'Main entry heading',
   '785-b' => 'Edition',
   '785-c' => 'Qualifying inform.',
   '785-d' => 'Place, publisher, and date of publication',
   '785-g' => 'Relationship inform.',
   '785-h' => 'Physical description',
   '785-i' => 'Display text',
   '785-k' => 'Series data for related item',
   '785-m' => 'Material-specific details',
   '785-n' => 'Note',
   '785-o' => 'Other item identifier',
   '785-q' => 'Parallel title',
   '785-r' => 'Report number',
   '785-s' => 'Uniform title',
   '785-t' => 'Title',
   '785-u' => 'Std. Techn. Report Number',
   '785-v' => 'Form subdivision',
   '785-w-auth' => 'Control subfield',
   '785-w-bibl' => 'Record control number',
   '785-x-auth' => 'General subdivision',
   '785-x-bibl' => 'ISSN',
   '785-y-auth' => 'Chronological subdivision',
   '785-y-bibl' => 'CODEN designation',
   '785-z-auth' => 'Geographic subdivision',
   '785-z-bibl' => 'ISBN',
   '786-6' => 'Linkage',
   '786-7' => 'Control subfield',
   '786-a' => 'Main entry heading',
   '786-b' => 'Edition',
   '786-c' => 'Qualifying inform.',
   '786-d' => 'Place, publisher, and date of publication',
   '786-g' => 'Relationship inform.',
   '786-h' => 'Physical description',
   '786-i' => 'Display text',
   '786-j' => 'Period of content',
   '786-k' => 'Series data for related item',
   '786-m' => 'Material-specific details',
   '786-n' => 'Note',
   '786-o' => 'Other item identifier',
   '786-r' => 'Report number',
   '786-s' => 'Uniform title',
   '786-t' => 'Title',
   '786-u' => 'Std. Techn. Report Number',
   '786-w' => 'Record control number',
   '786-x' => 'ISSN',
   '786-y' => 'CODEN designation',
   '786-z' => 'ISBN',
   '787-6' => 'Linkage',
   '787-7' => 'Control subfield',
   '787-a' => 'Main entry heading',
   '787-b' => 'Edition',
   '787-c' => 'Qualifying inform.',
   '787-d' => 'Place, publisher, and date of publication',
   '787-g' => 'Relationship inform.',
   '787-h' => 'Physical description',
   '787-i' => 'Display text',
   '787-k' => 'Series data for related item',
   '787-m' => 'Material-specific details',
   '787-n' => 'Note',
   '787-o' => 'Other item identifier',
   '787-r' => 'Report number',
   '787-s' => 'Uniform title',
   '787-t' => 'Title',
   '787-u' => 'Std. Techn. Report Number',
   '787-w' => 'Record control number',
   '787-x' => 'ISSN',
   '787-y' => 'CODEN designation',
   '787-z' => 'ISBN',
   '788-2' => 'Source',
   '788-5' => 'Institution',
   '788-6' => 'Linkage',
   '788-a' => 'Heading referred to',
   '788-i' => 'Explanatory text',
   '800-4' => 'Relator code',
   '800-6' => 'Linkage',
   '800-a' => 'Personal name',
   '800-b' => 'Numeration',
   '800-c' => 'Titles and other words associated with a name',
   '800-d' => 'Dates associated with a name',
   '800-e' => 'Relator term',
   '800-f' => 'Date of a work',
   '800-g' => 'Misc. inform.',
   '800-h' => 'Medium',
   '800-k' => 'Form subheading',
   '800-l' => 'Lang. of a work',
   '800-m' => 'Medium of performance for music',
   '800-n' => 'Number of part/section of a work',
   '800-o' => 'Arranged statement for music',
   '800-p' => 'Name of part/section of a work',
   '800-q' => 'Fuller form of name',
   '800-r' => 'Key for music',
   '800-s' => 'Version',
   '800-t' => 'Title of a work',
   '800-u' => 'Affiliation',
   '800-v' => 'Volume number/sequential designation',
   '810-4' => 'Relator code',
   '810-6' => 'Linkage',
   '810-a' => 'Corporate name or jurisdiction name as entry element',
   '810-b' => 'Subordinate unit',
   '810-c' => 'Location of meeting',
   '810-d' => 'Date of meeting or treaty signing',
   '810-e' => 'Relator term',
   '810-f' => 'Date of a work',
   '810-g' => 'Misc. inform.',
   '810-h' => 'Medium',
   '810-k' => 'Form subheading',
   '810-l' => 'Lang. of a work',
   '810-m' => 'Medium of performance for music',
   '810-n' => 'Number of part/section/meeting',
   '810-o' => 'Arranged statement for music',
   '810-p' => 'Name of part/section of a work',
   '810-r' => 'Key for music',
   '810-s' => 'Version',
   '810-t' => 'Title of a work',
   '810-u' => 'Affiliation',
   '810-v' => 'Volume number/sequential designation',
   '811-4' => 'Relator code',
   '811-6' => 'Linkage',
   '811-a' => 'Meeting name or jurisdiction name as entry element',
   '811-b' => 'Number',
   '811-c' => 'Location of meeting',
   '811-d' => 'Date of meeting',
   '811-e' => 'Subordinate unit',
   '811-f' => 'Date of a work',
   '811-g' => 'Misc. inform.',
   '811-h' => 'Medium',
   '811-k' => 'Form subheading',
   '811-l' => 'Lang. of a work',
   '811-n' => 'Number of part/section/meeting',
   '811-p' => 'Name of part/section of a work',
   '811-q' => 'Name of meeting following jurisdiction name entry element',
   '811-s' => 'Version',
   '811-t' => 'Title of a work',
   '811-u' => 'Affiliation',
   '811-v' => 'Volume number/sequential designation',
   '830-6' => 'Linkage',
   '830-a' => 'Uniform title',
   '830-d' => 'Date of treaty signing',
   '830-f' => 'Date of a work',
   '830-g' => 'Misc. inform.',
   '830-h' => 'Medium',
   '830-k' => 'Form subheading',
   '830-l' => 'Lang. of a work',
   '830-m' => 'Medium of performance for music',
   '830-n' => 'Number of part/section of a work',
   '830-o' => 'Arranged statement for music',
   '830-p' => 'Name of part/section of a work',
   '830-r' => 'Key for music',
   '830-s' => 'Version',
   '830-t' => 'Title of a work',
   '830-v' => 'Volume number/sequential designation',
   '840-a' => 'Title',
   '840-h' => 'Medium',
   '840-v' => 'Volume or number',
   '841-a' => 'Type of record',
   '841-b' => 'Fixed-length data elements',
   '841-e' => 'Encoding level',
   '842-3' => 'Materials specified',
   '842-7' => 'Fixed-length data elements of reproduction',
   '842-a' => 'Type of reproduction',
   '842-b' => 'Place of reproduction',
   '842-c' => 'Agency responsible for reproduction',
   '842-d' => 'Date of reproduction',
   '842-e' => 'Physical description of reproduction',
   '842-f' => 'Series statement of reproduction',
   '842-m' => 'Dates of publication',
   '842-n' => 'Note about reproduction',
   '844-3' => 'Materials specified',
   '844-a' => 'Use and reproduction',
   '844-b' => 'Jurisdiction',
   '844-c' => 'Authorization',
   '844-d' => 'Auth. users',
   '850-a' => 'Holding institution',
   '850-b' => 'Holdings',
   '850-d' => 'Inclusive dates',
   '850-e' => 'Retention statement',
   '851-3' => 'Materials specified',
   '851-6' => 'Linkage',
   '851-a' => 'Name',
   '851-b' => 'Institutional division',
   '851-c' => 'Street address',
   '851-d' => 'Country',
   '851-e' => 'Location of units',
   '851-f' => 'Item number',
   '851-g' => 'Repository location code',
   '852-2' => 'Source of class. scheme',
   '852-3' => 'Materials specified',
   '852-6' => 'Linkage',
   '852-8' => 'Link and sequence number',
   '852-a' => 'Location',
   '852-b' => 'Sublocation or collection',
   '852-c' => 'Shelving location',
   '852-e' => 'Address',
   '852-f' => 'Coded location qualifier',
   '852-g' => 'Non-coded location qualifier',
   '852-h' => 'Class. part',
   '852-i' => 'Item part',
   '852-j' => 'Shelving control number',
   '852-k' => 'Call number prefix',
   '852-l' => 'Shelving form of title',
   '852-m' => 'Call number suffix',
   '852-n' => 'Country code',
   '852-p' => 'Piece designation',
   '852-q' => 'Piece physical condition',
   '852-s' => 'Copyright article-fee code',
   '852-t' => 'Copy number',
   '852-x' => 'Nonpublic note',
   '852-z' => 'Public note',
   '853-3' => 'Materials specified',
   '853-8' => 'Link and sequence number',
   '853-a' => 'First level of enumeration',
   '853-b' => 'Second level of enumeration',
   '853-c' => 'Third level of enumeration',
   '853-d' => 'Fourth level of enumeration',
   '853-e' => 'Fifth level of enumeration',
   '853-f' => 'Sixth level of enumeration',
   '853-g' => 'Alternative numbering scheme, first level of enumeration',
   '853-h' => 'Alternative numbering scheme, second level of enumeration',
   '853-i' => 'First level of chronology',
   '853-j' => 'Second level of chronology',
   '853-k' => 'Third level of chronology',
   '853-l' => 'Fourth level of chronology',
   '853-m' => 'Alternative numbering scheme, chronology',
   '853-t' => 'Copy',
   '853-u' => 'Bibliographic units per next higher level',
   '853-w' => 'Frequency',
   '853-x' => 'Calendar change',
   '853-y' => 'Regularity pattern',
   '854-3' => 'Materials specified',
   '854-8' => 'Link and sequence number',
   '854-a' => 'First level of enumeration',
   '854-b' => 'Second level of enumeration',
   '854-c' => 'Third level of enumeration',
   '854-d' => 'Fourth level of enumeration',
   '854-e' => 'Fifth level of enumeration',
   '854-f' => 'Sixth level of enumeration',
   '854-g' => 'Alternative numbering scheme, first level of enumeration',
   '854-h' => 'Alternative numbering scheme, second level of enumeration',
   '854-i' => 'First level of chronology',
   '854-j' => 'Second level of chronology',
   '854-k' => 'Third level of chronology',
   '854-l' => 'Fourth level of chronology',
   '854-m' => 'Alternative numbering scheme, chronology',
   '854-o' => 'Type of supplementary material',
   '854-t' => 'Copy',
   '854-u' => 'Bibliographic units per next higher level',
   '854-v' => 'Numbering continuity',
   '854-w' => 'Frequency',
   '854-x' => 'Calendar change',
   '854-y' => 'Regularity pattern',
   '855-3' => 'Materials specified',
   '855-8' => 'Link and sequence number',
   '855-a' => 'First level of enumeration',
   '855-b' => 'Second level of enumeration',
   '855-c' => 'Third level of enumeration',
   '855-d' => 'Fourth level of enumeration',
   '855-e' => 'Fifth level of enumeration',
   '855-f' => 'Sixth level of enumeration',
   '855-g' => 'Alternative numbering scheme, first level of enumeration',
   '855-h' => 'Alternative numbering scheme, second level of enumeration',
   '855-i' => 'First level of chronology',
   '855-j' => 'Second level of chronology',
   '855-k' => 'Third level of chronology',
   '855-l' => 'Fourth level of chronology',
   '855-m' => 'Alternative numbering scheme, chronology',
   '855-o' => 'Type of index',
   '855-t' => 'Copy',
   '855-u' => 'Bibliographic units per next higher level',
   '855-v' => 'Numbering continuity',
   '855-w' => 'Frequency',
   '855-x' => 'Calendar change',
   '855-y' => 'Regularity pattern',
   '856-2' => 'Access method',
   '856-3' => 'Materials specified',
   '856-6' => 'Linkage',
   '856-a' => 'Host name',
   '856-b-bibl' => 'Access number',
   '856-b-clas' => 'Access number',
   '856-b-comm' => 'Access number',
   '856-b-hold' => 'IP address',
   '856-c' => 'Compression inform.',
   '856-d' => 'Path',
   '856-f' => 'Electronic name',
   '856-g-bibl' => 'Uniform Resource Name',
   '856-g-clas' => 'Electronic name--End of range',
   '856-g-comm' => 'Electronic name--End of range',
   '856-g-hold' => 'Electronic name--End of range',
   '856-h' => 'Processor of request',
   '856-i' => 'Instruction',
   '856-j' => 'Bits per second',
   '856-k' => 'Password',
   '856-l-bibl' => 'Logon',
   '856-l-clas' => 'Logon/login',
   '856-l-comm' => 'Logon/login',
   '856-l-hold' => 'Logon/login',
   '856-m' => 'Contact for access assistance',
   '856-n' => 'Name of location of host in subfield $a',
   '856-o' => 'Operating system',
   '856-p' => 'Port',
   '856-q-bibl' => 'Electronic format type',
   '856-q-clas' => 'File transfer mode)',
   '856-q-comm' => 'File transfer mode',
   '856-q-hold' => 'File transfer mode',
   '856-r' => 'Settings',
   '856-s' => 'File size',
   '856-t' => 'Terminal emulation',
   '856-u' => 'Uniform Resource Locator',
   '856-v' => 'Hours access method available',
   '856-w' => 'Record control number',
   '856-x' => 'Nonpublic note',
   '856-z' => 'Public note',
   '863-8' => 'Link and sequence number',
   '863-a' => 'First level of enumeration',
   '863-b' => 'Second level of enumeration',
   '863-c' => 'Third level of enumeration',
   '863-d' => 'Fourth level of enumeration',
   '863-e' => 'Fifth level of enumeration',
   '863-f' => 'Sixth level of enumeration',
   '863-g' => 'Alternative numbering scheme, first level of enumeration',
   '863-h' => 'Alternative numbering scheme, second level of enumeration',
   '863-i' => 'First level of chronology',
   '863-j' => 'Second level of chronology',
   '863-k' => 'Third level of chronology',
   '863-l' => 'Fourth level of chronology',
   '863-m' => 'Alternative numbering scheme, chronology',
   '863-n' => 'Converted Gregorian year',
   '863-p' => 'Piece designation',
   '863-q' => 'Piece physical condition',
   '863-s' => 'Copyright article-fee code',
   '863-t' => 'Copy number',
   '863-w' => 'Break indicator',
   '863-x' => 'Nonpublic note',
   '863-z' => 'Public note',
   '864-8' => 'Link and sequence number',
   '864-a' => 'First level of enumeration',
   '864-b' => 'Second level of enumeration',
   '864-c' => 'Third level of enumeration',
   '864-d' => 'Fourth level of enumeration',
   '864-e' => 'Fifth level of enumeration',
   '864-f' => 'Sixth level of enumeration',
   '864-g' => 'Alternative numbering scheme, first level of enumeration',
   '864-h' => 'Alternative numbering scheme, second level of enumeration',
   '864-i' => 'First level of chronology',
   '864-j' => 'Second level of chronology',
   '864-k' => 'Third level of chronology',
   '864-l' => 'Fourth level of chronology',
   '864-m' => 'Alternative numbering scheme, chronology',
   '864-n' => 'Converted Gregorian year',
   '864-o' => 'Title of supplementary material',
   '864-p' => 'Piece designation',
   '864-q' => 'Piece physical condition',
   '864-s' => 'Copyright article-fee code',
   '864-t' => 'Copy number',
   '864-w' => 'Break indicator',
   '864-x' => 'Nonpublic note',
   '864-z' => 'Public note',
   '865-8' => 'Link and sequence number',
   '865-a' => 'First level of enumeration',
   '865-b' => 'Second level of enumeration',
   '865-c' => 'Third level of enumeration',
   '865-d' => 'Fourth level of enumeration',
   '865-e' => 'Fifth level of enumeration',
   '865-f' => 'Sixth level of enumeration',
   '865-g' => 'Alternative numbering scheme, first level of enumeration',
   '865-h' => 'Alternative numbering scheme, second level of enumeration',
   '865-i' => 'First level of chronology',
   '865-j' => 'Second level of chronology',
   '865-k' => 'Third level of chronology',
   '865-l' => 'Fourth level of chronology',
   '865-m' => 'Alternative numbering scheme, chronology',
   '865-n' => 'Converted Gregorian year',
   '865-o' => 'Title of index',
   '865-p' => 'Piece designation',
   '865-q' => 'Piece physical condition',
   '865-s' => 'Copyright article-fee code',
   '865-t' => 'Copy number',
   '865-w' => 'Break indicator',
   '865-x' => 'Nonpublic note',
   '865-z' => 'Public note',
   '866-8' => 'Link and sequence number',
   '866-a' => 'Textual string',
   '866-x' => 'Nonpublic note',
   '866-z' => 'Public note',
   '867-8' => 'Link and sequence number',
   '867-a' => 'Textual holdings',
   '867-x' => 'Nonpublic note',
   '867-z' => 'Public note',
   '868-8' => 'Link and sequence number',
   '868-a' => 'Textual holdings',
   '868-x' => 'Nonpublic note',
   '868-z' => 'Public note',
   '876-3' => 'Materials specified',
   '876-8' => 'Link and sequence number',
   '876-a' => 'Internal item number',
   '876-b' => 'Invalid or cancelled internal item number',
   '876-c' => 'Cost',
   '876-d' => 'Date acquired',
   '876-e' => 'Source of acquisition',
   '876-h' => 'Use restrictions',
   '876-j' => 'Item status',
   '876-l' => 'Temporary location',
   '876-p' => 'Piece designation',
   '876-r' => 'Invalid or cancelled piece designation',
   '876-t' => 'Copy number',
   '876-x' => 'Nonpublic note',
   '876-z' => 'Public note',
   '877-3' => 'Materials specified',
   '877-8' => 'Link and sequence number',
   '877-a' => 'Internal item number',
   '877-b' => 'Invalid or cancelled internal item number',
   '877-c' => 'Cost',
   '877-d' => 'Date acquired',
   '877-e' => 'Source of acquisition',
   '877-h' => 'Use restrictions',
   '877-j' => 'Item status',
   '877-l' => 'Temporary location',
   '877-p' => 'Piece designation',
   '877-r' => 'Invalid or cancelled piece designation',
   '877-t' => 'Copy number',
   '877-x' => 'Nonpublic note',
   '877-z' => 'Public note',
   '878-3' => 'Materials specified',
   '878-8' => 'Link and sequence number',
   '878-a' => 'Internal item number',
   '878-b' => 'Invalid or cancelled internal item number',
   '878-c' => 'Cost',
   '878-d' => 'Date acquired',
   '878-e' => 'Source of acquisition',
   '878-h' => 'Use restrictions',
   '878-j' => 'Item status',
   '878-l' => 'Temporary location',
   '878-p' => 'Piece designation',
   '878-r' => 'Invalid or cancelled piece designation',
   '878-t' => 'Copy number',
   '878-x' => 'Nonpublic note',
   '878-z' => 'Public note',
   '880-6' => 'Linkage',
   '886-2' => 'Source of data',
   '886-a' => 'Tag of the foreign MARC field',
   '886-b' => 'Content of the foreign MARC field'
);

1;
