# * ====================================================================
# * Copyright (c) 1995,1996, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# *
# * With this file you should have received a file called 'License'.
# *
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer.
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================
#
# Module Z3950
#
# Definitions of values for Z39.50
#  - OID's
#     - constant to refer to OID
#     - OID to printable name mapping (%ASN1::OID_descriptions)
#     - name to OID mapping (%Z3950::RecordSyntaxes)
#     - OID to Structure definition (%ASN1::OID2Structure)
#    Make sure you update all the lists (or the appropriate ones) when
#    adding an OID.
#  - Attribute definitions (name to number mapping)
#  - Mapping arrays for ConfigFile parameters and simple names
#  - diagnostic messages
#  - tagset definitions (M, G, GILS)
#
# History:
#  1999-02-25  NWH   Initial release

package Z3950;

use strict;
#
# Various OID's for Z39.50 that might be encountered
#

$Z3950::OID = '1.2.840.10003';

$Z3950::OID_context                  = '1.2.840.10003.1';
$Z3950::OID_APDU                     = '1.2.840.10003.2';
$Z3950::OID_A_CIPB                   = '1.2.840.10003.2.1000.99.1';
$Z3950::OID_A_CIPB_22                = '1.2.840.10003.2.2000.99.1';
$Z3950::OID_attributeSet             = '1.2.840.10003.3';
$Z3950::OID_AS_Bib1                  = '1.2.840.10003.3.1';
$Z3950::OID_AS_Exp1                  = '1.2.840.10003.3.2';
$Z3950::OID_AS_Ext1                  = '1.2.840.10003.3.3';
$Z3950::OID_AS_CCL1                  = '1.2.840.10003.3.4';
$Z3950::OID_AS_GILS                  = '1.2.840.10003.3.5';
$Z3950::OID_AS_STAS                  = '1.2.840.10003.3.6';
$Z3950::OID_AS_CIP                   = '1.2.840.10003.3.1000.99.1';
$Z3950::OID_AS_CIP_22                = '1.2.840.10003.3.2000.99.1';
$Z3950::OID_diagnostic               = '1.2.840.10003.4';
$Z3950::OID_D_Bib1                   = '1.2.840.10003.4.1';
$Z3950::OID_D_Diag1                  = '1.2.840.10003.4.2';
$Z3950::OID_D_CIP                    = '1.2.840.10003.4.1000.99.1';
$Z3950::OID_D_CIP_22                 = '1.2.840.10003.4.2000.99.1';
$Z3950::OID_recordSyntax             = '1.2.840.10003.5';
$Z3950::OID_RS_Unimarc               = '1.2.840.10003.5.1';
$Z3950::OID_RS_Intermarc             = '1.2.840.10003.5.2';
$Z3950::OID_RS_CCF                   = '1.2.840.10003.5.3';
$Z3950::OID_RS_USmarc                = '1.2.840.10003.5.10';
$Z3950::OID_RS_UKmarc                = '1.2.840.10003.5.11';
$Z3950::OID_RS_Normarc               = '1.2.840.10003.5.12';
$Z3950::OID_RS_Librismarc            = '1.2.840.10003.5.13';
$Z3950::OID_RS_Danmarc               = '1.2.840.10003.5.14';
$Z3950::OID_RS_Finmarc               = '1.2.840.10003.5.15';
$Z3950::OID_RS_MAB                   = '1.2.840.10003.5.16';
$Z3950::OID_RS_Canmarc               = '1.2.840.10003.5.17';
$Z3950::OID_RS_SBN                   = '1.2.840.10003.5.18';
$Z3950::OID_RS_Picamarc              = '1.2.840.10003.5.19';
$Z3950::OID_RS_Ausmarc               = '1.2.840.10003.5.20';
$Z3950::OID_RS_Ibermarc              = '1.2.840.10003.5.21';
$Z3950::OID_RS_Explain               = '1.2.840.10003.5.100';
$Z3950::OID_RS_SUTRS                 = '1.2.840.10003.5.101';
$Z3950::OID_RS_OPAC                  = '1.2.840.10003.5.102';
$Z3950::OID_RS_Summary               = '1.2.840.10003.5.103';
$Z3950::OID_RS_GRS1                  = '1.2.840.10003.5.105';
$Z3950::OID_RS_Extended              = '1.2.840.10003.5.106';
$Z3950::OID_transferSyntax           = '1.2.840.10003.6';
$Z3950::OID_resourceReport           = '1.2.840.10003.7';
$Z3950::OID_RR_resource1             = '1.2.840.10003.7.1';
$Z3950::OID_RR_resource2             = '1.2.840.10003.7.2';
$Z3950::OID_accessControl            = '1.2.840.10003.8';
$Z3950::OID_AC_prompt1               = '1.2.840.10003.8.1';
$Z3950::OID_AC_des1                  = '1.2.840.10003.8.2';
$Z3950::OID_AC_krb1                  = '1.2.840.10003.8.3';
$Z3950::OID_extendedService          = '1.2.840.10003.9';
$Z3950::OID_ES_PersistentResultSet   = '1.2.840.10003.9.1';
$Z3950::OID_ES_PersistentQuery       = '1.2.840.10003.9.2';
$Z3950::OID_ES_PeriodicQuerySchedule = '1.2.840.10003.9.3';
$Z3950::OID_ES_ItemOrder             = '1.2.840.10003.9.4';
$Z3950::OID_ES_DatabaseUpdate        = '1.2.840.10003.9.5';
$Z3950::OID_ES_ExportSpecification   = '1.2.840.10003.9.6';
$Z3950::OID_ES_ExportInvocation      = '1.2.840.10003.9.7';
$Z3950::OID_ES_CIPorderExtService    = '1.2.840.10003.9.1000.99.1';
$Z3950::OID_ES_CIPorderExtService_22 = '1.2.840.10003.9.2000.99.1';
$Z3950::OID_userInfoFormat           = '1.2.840.10003.10';
$Z3950::OID_UIF_SearchResult1        = '1.2.840.10003.10.1';
$Z3950::OID_elementSpec              = '1.2.840.10003.11';
$Z3950::OID_ElS_eSpec                = '1.2.840.10003.11.1';
$Z3950::OID_variantSet               = '1.2.840.10003.12';
$Z3950::OID_VS_variant1              = '1.2.840.10003.12.1';
$Z3950::OID_schema                   = '1.2.840.10003.13';
$Z3950::OID_S_WAIS                   = '1.2.840.10003.13.1';
$Z3950::OID_S_GILS                   = '1.2.840.10003.13.2';
$Z3950::OID_S_collCIP                = '1.2.840.10003.13.1000.99.1';
$Z3950::OID_S_prodCIP                = '1.2.840.10003.13.1000.99.2';
$Z3950::OID_S_userCIP                = '1.2.840.10003.13.1000.99.4';
$Z3950::OID_S_collCIP_22             = '1.2.840.10003.13.2000.99.1';
$Z3950::OID_S_prodCIP_22             = '1.2.840.10003.13.2000.99.2';
$Z3950::OID_S_userCIP_22             = '1.2.840.10003.13.2000.99.4';
$Z3950::OID_tagSet                   = '1.2.840.10003.14';
$Z3950::OID_TS_M                     = '1.2.840.10003.14.1';
$Z3950::OID_TS_G                     = '1.2.840.10003.14.2';
$Z3950::OID_TS_STAS                  = '1.2.840.10003.14.3';
$Z3950::OID_TS_CIP                   = '1.2.840.10003.14.1000.99.1';
$Z3950::OID_TS_CIP_22                = '1.2.840.10003.14.2000.99.1';
$Z3950::OID_RS_HTML                  = '1.2.840.10003.5.109.3';
$Z3950::OID_RS_SGML                  = '1.2.840.10003.5.109.9';
$Z3950::OID_RS_XML                   = '1.2.840.10003.5.109.10';
$Z3950::OID_RS_SGML_OLD              = '1.2.840.10003.1000.34.2';
$Z3950::OID_RS_HTML_OLD              = '1.2.840.10003.1000.34.1';

%ASN1::OID_descriptions = (%ASN1::OID_descriptions,
   $Z3950::OID                          => 'Z39.50',
   $Z3950::OID_context                  => 'Context',
   $Z3950::OID_APDU                     => 'APDU',
   $Z3950::OID_A_CIPB                   => 'CIP Release B APDU',
   $Z3950::OID_attributeSet             => 'Attribute Set',
   $Z3950::OID_AS_Bib1                  => 'Bib-1 attribute set',
   $Z3950::OID_AS_Exp1                  => 'Exp-1 attribute set',
   $Z3950::OID_AS_Ext1                  => 'Ext-1 attribute set',
   $Z3950::OID_AS_CCL1                  => 'CCL attribute set',
   $Z3950::OID_AS_GILS                  => 'GILS attribute set',
   $Z3950::OID_AS_STAS                  => 'STAS attribute set',
   $Z3950::OID_AS_CIP                   => 'CIP attribute set',
   $Z3950::OID_AS_CIP_22                => 'CIP attribute set (CIP 2.2)',
   $Z3950::OID_diagnostic               => 'Diagnostic',
   $Z3950::OID_D_Bib1                   => 'Bib-1 diagnostic',
   $Z3950::OID_D_Diag1                  => 'Diag-1 diagnostic',
   $Z3950::OID_D_CIP                    => 'CIP diagnostic',
   $Z3950::OID_D_CIP_22                 => 'CIP diagnostic (CIP 2.2)',
   $Z3950::OID_recordSyntax             => 'Record Syntax',
   $Z3950::OID_RS_Unimarc               => 'Unimarc record syntax',
   $Z3950::OID_RS_Intermarc             => 'Intermarc record syntax',
   $Z3950::OID_RS_CCF                   => 'CCF record syntax',
   $Z3950::OID_RS_USmarc                => 'USmarc record syntax',
   $Z3950::OID_RS_UKmarc                => 'UKmarc record syntax',
   $Z3950::OID_RS_Normarc               => 'Normarc record syntax',
   $Z3950::OID_RS_Librismarc            => 'Librismarc record syntax',
   $Z3950::OID_RS_Danmarc               => 'Danmarc record syntax',
   $Z3950::OID_RS_Finmarc               => 'Finmarc record syntax',
   $Z3950::OID_RS_MAB                   => 'MAB record syntax',
   $Z3950::OID_RS_Canmarc               => 'Canmarc record syntax',
   $Z3950::OID_RS_SBN                   => 'SBN record syntax',
   $Z3950::OID_RS_Picamarc              => 'Picamarc record syntax',
   $Z3950::OID_RS_Ausmarc               => 'Ausmarc record syntax',
   $Z3950::OID_RS_Ibermarc              => 'Ibermarc record syntax',
   $Z3950::OID_RS_Explain               => 'Explain record syntax',
   $Z3950::OID_RS_SUTRS                 => 'SUTRS record syntax',
   $Z3950::OID_RS_OPAC                  => 'OPAC record syntax',
   $Z3950::OID_RS_Summary               => 'Summary record syntax',
   $Z3950::OID_RS_GRS1                  => 'GRS1 record syntax',
   $Z3950::OID_RS_Extended              => 'Extended record syntax',
   $Z3950::OID_RS_HTML                  => 'HTML',
   $Z3950::OID_RS_SGML                  => 'SGML',
   $Z3950::OID_RS_XML                   => 'XML',
   $Z3950::OID_RS_HTML_OLD              => 'HTML (legacy)',
   $Z3950::OID_RS_SGML_OLD              => 'SGML (legacy)',
   $Z3950::OID_transferSyntax           => 'Transfer Syntax',
   $Z3950::OID_resourceReport           => 'Resource Report',
   $Z3950::OID_RR_resource1             => 'type 1 resource report',
   $Z3950::OID_RR_resource2             => 'type 2 resource report',
   $Z3950::OID_accessControl            => 'Access Control',
   $Z3950::OID_AC_prompt1               => 'Prompt access control',
   $Z3950::OID_AC_des1                  => 'DES access control',
   $Z3950::OID_AC_krb1                  => 'KRB access control',
   $Z3950::OID_extendedService          => 'Extended Service',
   $Z3950::OID_ES_PersistentResultSet   => 'Persistent Result Set ES',
   $Z3950::OID_ES_PersistentQuery       => 'Persistent Query ES',
   $Z3950::OID_ES_PeriodicQuerySchedule => 'Periodic Query Schedule ES',
   $Z3950::OID_ES_ItemOrder             => 'Item Order ES',
   $Z3950::OID_ES_DatabaseUpdate        => 'Database Update ES',
   $Z3950::OID_ES_ExportSpecification   => 'Export Specification ES',
   $Z3950::OID_ES_ExportInvocation      => 'Export Invocation ES',
   $Z3950::OID_ES_CIPorderExtService    => 'Order ES',
   $Z3950::OID_ES_CIPorderExtService_22 => 'Order ES (CIP 2.2)',
   $Z3950::OID_userInfoFormat           => 'User Info Format',
   $Z3950::OID_UIF_SearchResult1        => 'Search Result',
   $Z3950::OID_elementSpec              => 'Element Spec',
   $Z3950::OID_ElS_eSpec                => 'type 1 element specification',
   $Z3950::OID_variantSet               => 'Variant Set',
   $Z3950::OID_VS_variant1              => 'type 1 variant set',
   $Z3950::OID_schema                   => 'Schema',
   $Z3950::OID_S_WAIS                   => 'WAIS schema',
   $Z3950::OID_S_GILS                   => 'GILS schema',
   $Z3950::OID_S_collCIP                => 'CIP collection schema',
   $Z3950::OID_S_prodCIP                => 'CIP product schema',
   $Z3950::OID_S_userCIP                => 'CIP user schema',
   $Z3950::OID_S_collCIP_22             => 'CIP collection schema (CIP 2.2)',
   $Z3950::OID_S_prodCIP_22             => 'CIP product schema (CIP 2.2)',
   $Z3950::OID_S_userCIP_22             => 'CIP user schema (CIP 2.2)',
   $Z3950::OID_tagSet                   => 'Tag Set',
   $Z3950::OID_TS_M                     => 'tagSet M',
   $Z3950::OID_TS_G                     => 'tagSet G',
   $Z3950::OID_TS_STAS                  => 'tagSet STAS',
   $Z3950::OID_TS_CIP                   => 'tagSet CIP',
   $Z3950::OID_TS_CIP_22                => 'tagSet CIP (CIP 2.2)'
);

# Used in External record to decode the substructure

%ASN1::OID2Structure = (%ASN1::OID2Structure,
   # single-ASN1-type
   $Z3950::OID_RS_Explain=>\%Z3950::ASN1::RecordSyntax_explain::Explain_Record,
   $Z3950::OID_RS_SUTRS=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,
   $Z3950::OID_RS_OPAC=>\%Z3950::ASN1::RecordSyntax_opac::OPACRecord,
   $Z3950::OID_RS_Summary=>\%Z3950::ASN1::RecordSyntax_summary::BriefBib,
   $Z3950::OID_RS_GRS1=>\%Z3950::ASN1::RecordSyntax_generic::GenericRecord,
   $Z3950::OID_RS_Extended=>\%Z3950::ASN1::RecordSyntax_ESTaskPackage::TaskPackage,
   $Z3950::OID_RS_HTML=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,
   $Z3950::OID_RS_HTML_OLD=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,
   $Z3950::OID_RS_SGML=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,
   $Z3950::OID_RS_SGML_OLD=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,
   $Z3950::OID_RS_XML=>\%Z3950::ASN1::RecordSyntax_SUTRS::SutrsRecord,

   # octet-aligned
   $Z3950::OID_RS_Unimarc=>undef,
   $Z3950::OID_RS_Intermarc=>undef,
   $Z3950::OID_RS_CCF=>undef,
   $Z3950::OID_RS_USmarc=>undef,
   $Z3950::OID_RS_UKmarc=>undef,
   $Z3950::OID_RS_Normarc=>undef,
   $Z3950::OID_RS_Librismarc=>undef,
   $Z3950::OID_RS_Danmarc=>undef,
   $Z3950::OID_RS_Finmarc=>undef,
   $Z3950::OID_RS_MAB=>undef,
   $Z3950::OID_RS_Canmarc=>undef,
   $Z3950::OID_RS_SBN=>undef,
   $Z3950::OID_RS_Picamarc=>undef,
   $Z3950::OID_RS_Ausmarc=>undef,
   $Z3950::OID_RS_Ibermarc=>undef,
);



#
# The Attributes
#

$Z3950::Bib1_Use_Type = 1;
%Z3950::Bib1_Use = (
   'personal name'                 =>    1,
   'corporate name'                =>    2,
   'conference name'               =>    3,
   'title'                         =>    4,
   'title series'                  =>    5,
   'title uniform'                 =>    6,
   'isbn'                          =>    7,
   'issn'                          =>    8,
   'lc card number'                =>    9,
   'bnb card number'               =>   10,
   'bgf number'                    =>   11,
   'local number'                  =>   12,
   'dewey classification'          =>   13,
   'udc classification'            =>   14,
   'bliss classification'          =>   15,
   'lc call number'                =>   16,
   'nlm call number'               =>   17,
   'nal call number'               =>   18,
   'mos call number'               =>   19,
   'local classification'          =>   20,
   'subject heading'               =>   21,
   'subject rameau'                =>   22,
   'bdi index subject'             =>   23,
   'inspec subject'                =>   24,
   'mesh subject'                  =>   25,
   'pa subject'                    =>   26,
   'lc subject heading'            =>   27,
   'rvm subject heading'           =>   28,
   'local subject index'           =>   29,
   'date'                          =>   30,
   'date of publication'           =>   31,
   'date of acquisition'           =>   32,
   'title key'                     =>   33,
   'title collective'              =>   34,
   'title parallel'                =>   35,
   'title cover'                   =>   36,
   'title added title page'        =>   37,
   'title caption'                 =>   38,
   'title running'                 =>   39,
   'title spine'                   =>   40,
   'title other variant'           =>   41,
   'title former'                  =>   42,
   'title abbreviated'             =>   43,
   'title expanded'                =>   44,
   'subject precise'               =>   45,
   'subject rswk'                  =>   46,
   'subject subdivision'           =>   47,
   'number national biblio.'       =>   48,
   'number legal deposit'          =>   49,
   'number government publication' =>   50,
   'number music publisher'        =>   51,
   'number db'                     =>   52,
   'number local call'             =>   53,
   'code--language'                =>   54,
   'code--geographic area'         =>   55,
   'code--institution'             =>   56,
   'name and title'                =>   57,
   'name geographic'               =>   58,
   'place publication'             =>   59,
   'coden'                         =>   60,
   'microform generation'          =>   61,
   'abstract'                      =>   62,
   'note'                          =>   63,
   'author-title'                  => 1000,
   'record type'                   => 1001,
   'name'                          => 1002,
   'author'                        => 1003,
   'author-name personal'          => 1004,
   'author-name corporate'         => 1005,
   'author-name conference'        => 1006,
   'identifier--standard'          => 1007,
   'subject--lc\'s children\'s'    => 1008,
   'subject name--personal'        => 1009,
   'body of text'                  => 1010,
   'date/time added to db'         => 1011,
   'data/time last modified'       => 1012,
   'authority/format id'           => 1013,
   'concept-text'                  => 1014,
   'concept-reference'             => 1015,
   'any'                           => 1016,
   'server-choice'                 => 1017,
   'publisher'                     => 1018,
   'record-source'                 => 1019,
   'editor'                        => 1020,
   'bib-level'                     => 1021,
   'geographic-class'              => 1022,
   'indexed-by'                    => 1023,
   'map-scale'                     => 1024,
   'music-key'                     => 1025,
   'related-periodical'            => 1026,
   'report-number'                 => 1027,
   'stock-number'                  => 1028,
   'thematic-number'               => 1030,
   'material-type'                 => 1031,
   'doc-id'                        => 1032,
   'host-item'                     => 1033,
   'content-type'                  => 1034,
   'anywhere'                      => 1035,
   'author-title-subject'          => 1036
);
$Z3950::Bib1_Relation_Type = 2;
%Z3950::Bib1_Relation = (
   'less than'          =>   1,
   '<'                  =>   1,
   'less than or equal' =>   2,
   '=<'                 =>   2,
   '<='                 =>   2,
   'equal'              =>   3,
   '='                  =>   3,
   '=='                 =>   3,
   'greater or equal'   =>   4,
   '=>'                 =>   4,
   '>='                 =>   4,
   'greater than'       =>   5,
   '>'                  =>   5,
   'not equal'          =>   6,
   '!='                 =>   6,
   '<>'                 =>   6,
   'phonetic'           => 100,
   'stem'               => 101,
   'relevance'          => 102,
   'matches always'     => 103,
   'always'             => 103
);
$Z3950::Bib1_Position_Type = 3;
%Z3950::Bib1_Position = (
   'first in field',       => 1,
   'first in subfield',    => 2,
   'any position in field' => 3
);
$Z3950::Bib1_Structure_Type = 4;
%Z3950::Bib1_Structure = (
   'phrase'               =>   1,
   'word'                 =>   2,
   'key'                  =>   3,
   'year'                 =>   4,
   'date (normalized)'    =>   5,
   'word list'            =>   6,
   'date (un-normalized)' => 100,
   'name (normalized)'    => 101,
   'name (un-normalized)' => 102,
   'structure'            => 103,
   'urx'                  => 104,
   'free-form-text'       => 105,
   'document-text'        => 106,
   'local number'         => 107,
   'string'               => 108,
   'numeric string'       => 109
);
$Z3950::Bib1_Truncation_Type = 5;
%Z3950::Bib1_Truncation = (
   'right truncation'         =>   1,
   'left truncation'          =>   2,
   'left and right'           =>   3,
   'do not truncate'          => 100,
   'process # in search term' => 101,
   'regExpr1'                 => 102,
   'regExpr2'                 => 103
);
$Z3950::Bib1_Completeness_Type = 6;
%Z3950::Bib1_Completeness = (
   'incomplete subfield' => 1,
   'complete subfield'   => 2,
   'complete field'      => 3
);


$Z3950::Exp1_Use_Type = 1;
%Z3950::Exp1_Use = (
   'explain category'      =>  1,
   'human string language' =>  2,
   'database name'         =>  3,
   'target name'           =>  4,
   'attribute set oid'     =>  5,
   'record syntax oid'     =>  6,
   'tag set oid'           =>  7,
   'extended service oid'  =>  8,
   'date added'            =>  9,
   'date changed'          => 10,
   'date expires'          => 11,
   'element set name'      => 12,
   'processing context'    => 13,
   'processing name'       => 14,
   'term list name'        => 15,
   'schema oid'            => 16,
   'producer'              => 17,
   'supplier'              => 18,
   'availability'          => 19,
   'proprietary'           => 20,
   'user fee'              => 21,
   'variant set oid'       => 22,
   'unit system'           => 23,
   'keyword'               => 25,
   'explain database'      => 26,
   'processing oid'        => 27
);
$Z3950::Exp1_Relation_Type      = $Z3950::Bib1_Relation_Type;
%Z3950::Exp1_Relation           = %Z3950::Bib1_Relation;
$Z3950::Exp1_Position_Type      = $Z3950::Bib1_Position_Type;
%Z3950::Exp1_Position           = %Z3950::Bib1_Position;
$Z3950::Exp1_Structure_Type     = $Z3950::Bib1_Structure_Type;
%Z3950::Exp1_Structure          = %Z3950::Bib1_Structue;
$Z3950::Exp1_Truncation_Type    = $Z3950::Bib1_Truncation_Type;
%Z3950::Exp1_Truncation         = %Z3950::Bib1_Truncation;
$Z3950::Exp1_Completeness_Type  = $Z3950::Bib1_Completeness_Type;
%Z3950::Exp1_Completeness       = %Z3950::Bib1_Completeness;

$Z3950::Ext1_Use_Type = 1;
%Z3950::Ext1_Use = (
   'user id'            => 1,
   'package name'       => 2,
   'creation date/time' => 3,
   'task status'        => 4,
   'package type'       => 5,
   'retention time'     => 6,
   'target reference'   => 7
);
$Z3950::Ext1_Permission_Type = 2;
%Z3950::Ext1_Permission = (
   'Delete'             => 1,
   'Modify'             => 2,
   'Modify permissions' => 3,
   'Present'            => 4,
   'Invoke'             => 5,
   'Any'                => 6
);


%Z3950::geo_Use = (
   'west bounding coordinate'  => 2038,
   'east bounding coordinate'  => 2039,
   'north bounding coordinate' => 2040,
   'south bounding coordinate' => 2041
);

%Z3950::Any999_Use = ( 'any' => 999 );
%Z3950::Any1035_Use = ( 'any' => 1035 );



# Arrays for translation from ConfigFile parameters to references or scalars.
#
%Z3950::AttributeSets = (                 # keys must be all lowercase
   'bib1'   => \%Z3950::Bib1_Use,
   'exp1'   => \%Z3950::Exp1_Use,
   'ext1'   => \%Z3950::Ext1_Use,
#   'fgdc'   => \%Z3950::FGDC_Use,         # attribute set is external
   'geo'    => \%Z3950::geo_Use,
   'any999' => \%Z3950::Any999_Use,
   'any1035'=> \%Z3950::Any1035_Use
);
%Z3950::RecordSyntaxes = (
   'unimarc'   => $Z3950::OID_RS_Unimarc,
   'intermarc' => $Z3950::OID_RS_Intermarc,
   'ccf'       => $Z3950::OID_RS_CCF,
   'usmarc'    => $Z3950::OID_RS_USmarc,
   'ukmarc'    => $Z3950::OID_RS_UKmarc,
   'normarc'   => $Z3950::OID_RS_Normarc,
   'librismarc'=> $Z3950::OID_RS_Librismarc,
   'danmarc'   => $Z3950::OID_RS_Danmarc,
   'finmarc'   => $Z3950::OID_RS_Finmarc,
   'mab'       => $Z3950::OID_RS_MAB,
   'canmarc'   => $Z3950::OID_RS_Canmarc,
   'sbn'       => $Z3950::OID_RS_SBN,
   'picmarc'   => $Z3950::OID_RS_Picamarc,
   'ausmarc'   => $Z3950::OID_RS_Ausmarc,
   'ibermarc'  => $Z3950::OID_RS_Ibermarc,
   'explain'   => $Z3950::OID_RS_Explain,
   'sutrs'     => $Z3950::OID_RS_SUTRS,
   'opac'      => $Z3950::OID_RS_OPAC,
   'summary'   => $Z3950::OID_RS_Summary,
   'grs1'      => $Z3950::OID_RS_GRS1,
   'extended'  => $Z3950::OID_RS_Extended,
   'html'      => $Z3950::OID_RS_HTML,
   'sgml'      => $Z3950::OID_RS_SGML,
   'xml'       => $Z3950::OID_RS_XML
);


# Diagnostic messages

%Z3950::Bib1_Diagnostics = (
     1 => 'Permanent system error',
     2 => 'Temporary system error',
     3 => 'Unsupported search',
     4 => 'Terms only exclusion (stop) words',
     5 => 'Too many argument words',
     6 => 'Too many boolean operators',
     7 => 'Too many truncated words',
     8 => 'Too many incomplete subfields',
     9 => 'Truncated words too short',
    10 => 'Invalid format for record number (search term)',
    11 => 'Too many characters in search statement',
    12 => 'Too many records retrieved',
    13 => 'Present request out-of-range',
    14 => 'System error in presenting records',
    15 => 'Record not authorized to be sent intersystem',
    16 => 'Record exceeds Preferred-message-size',
    17 => 'Record exceeds Exceptional-record-size',
    18 => 'Result set not supported as a search term',
    19 => 'Only single result set as search term supported',
    20 => 'Only ANDing of a single result set as search term',
    21 => 'Result set exists and replace indicator off',
    22 => 'Result set naming not supported',
    23 => 'Specified combination of databases not supported',
    24 => 'Element set names not supported',
    25 => 'Specified element set name not valid for specified database',
    26 => 'Only generic form of element set name supported',
    27 => 'Result set no longer exists - unilaterally deleted by target',
    28 => 'Result set is in use',
    29 => 'One of the specified databases is locked',
    30 => 'Specified result set does not exist',
    31 => 'Resources exhausted - no results available',
    32 => 'Resources exhausted - unpredictable partial results available',
    33 => 'Resources exhausted - valid subset of results available',
   100 => '(unspecified) error',
   101 => 'Access-control failure',
   102 => 'Challenge required, could not be issued - operation terminated',
   103 => 'Challenge required, could not be issued - record not included',
   104 => 'Challenge failed - record not included',
   105 => 'Terminated at origin request',
   106 => 'No abstract syntaxes agreed to for this record',
   107 => 'Query type not supported',
   108 => 'Malformed query',
   109 => 'Database unavailable',
   110 => 'Operator unsupported',
   111 => 'Too many databases specified',
   112 => 'Too many result sets created',
   113 => 'Unsupported attribute type',
   114 => 'Unsupported Use attribute',
   115 => 'Unsupported term value for Use attribute',
   116 => 'Use attribute required but not supplied',
   117 => 'Unsupported Relation attribute',
   118 => 'Unsupported Structure attribute',
   119 => 'Unsupported Position attribute',
   120 => 'Unsupported Truncation attribute',
   121 => 'Unsupported Attribute Set',
   122 => 'Unsupported Completeness attribute',
   123 => 'Unsupported attribute combination',
   124 => 'Unsupported coded value for term',
   125 => 'Malformed search term',
   126 => 'Illegal term value for attribute',
   127 => 'Unparsable format for un-normalized value',
   128 => 'Illegal result set name',
   129 => 'Proximity search of sets not supported',
   130 => 'Illegal result set in proximity search',
   131 => 'Unsupported proximity relation',
   132 => 'Unsupported proximity unit code',
   201 => 'Proximity not supported with this attribute combination',
   202 => 'Unsupported distance for proximity',
   203 => 'Ordered flag not supported for proximity',
   205 => 'Only zero step size supported for Scan',
   206 => 'Specified step size not supported for Scan',
   207 => 'Cannot sort according to sequence',
   208 => 'No result set name supplied on Sort',
   209 => 'Generic sort not supported (database-specific sort only supported)',
   210 => 'Database specific sort not supported',
   211 => 'Too many sort keys',
   212 => 'Duplicate sort keys',
   213 => 'Unsupported missing data action',
   214 => 'Illegal sort relation',
   215 => 'Illegal case value',
   216 => 'Illegal missing data action',
   217 => 'Segmentation: Cannot guarantee records will fit in specified segments',
   218 => 'ES: Package name already in use',
   219 => 'ES: no such package, on modify/delete',
   220 => 'ES: quota exceeded',
   221 => 'ES: extended service type not supported',
   222 => 'ES: permission denied on ES - id not authorized',
   223 => 'ES: permission denied on ES - cannot modify or delete',
   224 => 'ES: immediate execution failed',
   225 => 'ES: immediate execution not supported for this service',
   226 => 'ES: immediate execution not supported for these parameters',
   227 => 'No data available in requested record syntax',
   228 => 'Scan: malformed scan',
   229 => 'Term type not supported',
   230 => 'Sort: too many input results',
   231 => 'Sort: incompatible record formats',
   232 => 'Scan: term list not supported',
   233 => 'Scan: unsupported value of position-in-response',
   234 => 'Too many index terms processed',
   235 => 'Database does not exist',
   236 => 'Access to specified database denied',
   237 => 'Sort: illegal sort',
   238 => 'Record not available in requested syntax',
   239 => 'Record syntax not supported',
   240 => 'Scan: Resources exhausted looking for satisfying terms',
   241 => 'Scan: Beginning or end of term list',
   242 => 'Segmentation: max-segment-size too small to segment record',
   243 => 'Present:  additional-ranges parameter not supported',
   244 => 'Present:  comp-spec parameter not supported',
   245 => 'Type-1 query: restriction ("resultAttr") operand not supported',
   246 => 'Type-1 query: "complex" attributeValue not supported',
   247 => 'Type-1 query: "attributeSet" as part of AttributeElement not supported'
);

%Z3950::Diag1_Diagnostics   = %Z3950::Bib1_Diagnostics;



#
# Definition of the tag sets
#

%Z3950::tagSetM = (
   1 => 'Schema Identifier',
   2 => 'Elements Ordered',
   3 => 'Element Ordering',
   4 => 'Default Tag Type',
   5 => 'Default Variant Set Id',
   6 => 'Default Variant Spec',
   7 => 'Processing Instructions',
   8 => 'Record Usage',
   9 => 'Restriction',
   10 => 'Rank',
   11 => 'User Message',
   12 => 'URL',
   13 => 'Record',
   14 => 'Local Control Number',
   15 => 'Creation Date',
   16 => 'Last Modification Date',
   17 => 'Last Review Date',
   18 => 'Score',
   19 => 'Well Known',
   20 => 'Record Wrapper',
   21 => 'Default Tag Set Id'
);

%Z3950::tagSetG = (
    1 => 'Title',
    2 => 'Author',
    3 => 'Publication Place',
    4 => 'Publication Date',
    5 => 'Document Id',
    6 => 'Abstract',
    7 => 'Name',
    8 => 'Date',
    9 => 'Body Of Display',
   10 => 'Organisation',
   11 => 'Postal Address',
   12 => 'Network Address',
   13 => 'e-Mail Address',
   14 => 'Phone Number',
   15 => 'Fax Number',
   16 => 'Country',
   17 => 'Description',
   18 => 'Time',
   19 => 'Document Content'
);

%Z3950::tagSetGILS = (
    1 => 'Control Identifier',
    2 => 'Street Address',
    3 => 'City',
    4 => 'State or Province',
    5 => 'ZIP or Postal Code',
    6 => 'Hours Of Service',
    7 => 'Resource Description',
    8 => 'Technical Prerequisites',
    9 => 'West Bounding Coord',
   10 => 'East Bounding Coord.',
   11 => 'North Bounding Coord.',
   12 => 'South Bounding Coord.',
   13 => 'Place Keyword',
   14 => 'Place Keyword Thesaurus',
   15 => 'Beginning Date',
   16 => 'Time Period',
   17 => 'Linkage',
   18 => 'Linkage Type',
   19 => 'Record Source',
   20 => 'Controlled Term',
   21 => 'Subject Thesaurus',
   22 => 'Uncontrolled Term',
   23 => 'Original Control Identifier',
   24 => 'Record Review Date',
   25 => 'General Access Constraints',
   26 => 'Originator Dissemination Control',
   27 => 'Security Classification Control',
   28 => 'Order Information',
   29 => 'Cost',
   30 => 'Cost Information',
   31 => 'Schedule Number',
   32 => 'Language Of Resource',
   33 => 'Medium',
   34 => 'Language Of Record',
   35 => 'Relationship',
   36 => 'Ending Date',
   51 => 'Purpose',
   52 => 'Originator',
   53 => 'Access Constraints',
   54 => 'Use Constraints',
   55 => 'Order Process',
   56 => 'Agency Program',
   57 => 'Sources Of Data',
   58 => 'Methodology',
   59 => 'Supplemental Information',
   71 => 'Availability',
   72 => 'Spatial Domain',
   90 => 'Distributor',
   91 => 'Bounding Coordinates',
   92 => 'Place',
   93 => 'Time Period',
   94 => 'Point Of Contact',
   95 => 'Controlled Subject Index',
   96 => 'Subject Terms Controlled',
   97 => 'Subject Terms Uncontrolled',
   98 => 'Cross Reference',
   99 => 'Available Linkage',
   100=> 'Cross Reference Linkage',
   101=> 'Time Period Structured',
   102=> 'Available Time Structured'
);
1;
