#!/usr/local/bin/perl
# * ====================================================================
# * Copyright (c) 1999, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# *
# * With this file you should have received a file called 'License'.
# *
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer.
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================
#

# Converts files between XER and BER. Any combination of the two
# encodings can be chosen (so XER-XER is a valid choice as well).

use ASN1;

use Z3950::ASN1::Z39_50_APDU_1995;
use Z3950::ASN1::RecordSyntax_generic;
use Z3950::ASN1::RecordSyntax_SUTRS;

use Z3950::Z3950;

$::inputfile = undef;
$::inputtype = 'BER';
$::outputfile = undef;
$::outputtype = 'XER';

# Read the command line parameters
#
while ( $arg = shift @ARGV ) {
   if ( $arg eq '-I' and $::inputfile = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-i' and $::inputtype = uc(shift @ARGV) ) {
      # nop
   } elsif ( $arg eq '-O' and $::outputfile = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-o' and $::outputtype = uc(shift @ARGV) ) {
      # nop
   } elsif ( $arg eq '-D' and $debuglist = shift @ARGV ) {
      $ASN1::debug = $debug = 1
         if $debuglist =~ m/\bmain\b/i;
      $ASN1::debug_received = 1
         if $debuglist =~ m/\breceived\b/i;
      $ASN1::debug_sent = 1
         if $debuglist =~ m/\bsent\b/i;
      $ASN1::BER::debug = 1
         if $debuglist =~ m/\bBER\b/i;
      $ASN1::XER::debug = 1
         if $debuglist =~ m/\bXER\b/i;
      my $key;
      foreach $key ( split m/[^a-z_]+/i, $debuglist ) {
         $key =~ s/^debug_//;
         eval '$ASN1::XER::debug_'.$key.'=1; $ASN1::BER::debug_'.$key.'=1;';
      }
   } else {
      die "Syntax: $0 [options]\n"
        . " with  -D    a comma separated list of (main,received,sent,BER,XER) []\n"
        . "       -i    type of input file [$::inputtype]\n"
        . "       -I    name of input file []\n"
        . "       -o    type of output file [$::outputtype]\n"
        . "       -O    name of output file []\n";

   }
}

die "No inputfile specified"
   unless $::inputfile;
die "No outputfile specified"
   unless $::outputfile;

warn "Processing $inputfile ('$inputtype'), output in $outputfile ('$outputtype')"
   if $::debug;

# open the input and output file
open INFILE, $inputfile
   or die "Could not open $inputfile for reading, $!";
open OUTFILE, '>'.$outputfile
   or die "Could not open $outputfile for writing, $!";

# read the record from the file
my $PDU = &ASN1::receivePDU(\*INFILE, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $inputtype, 'inPDU')
   or die "receivePDU returned: $@";

print STDERR '-'x79 . "\n"
   if $::debug;

# write the requested format into the destination file again
&ASN1::sendPDU(\*OUTFILE, $PDU, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $outputtype, 'outPDU')
   or warn $@;

close INFILE;
close OUTFILE;
