#!/usr/local/bin/perl
# * ====================================================================
# * Copyright (c) 1995,1996, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# *
# * With this file you should have received a file called 'License'.
# *
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer.
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================
#

use ASN1;
use Z3950::ASN1::RecordSyntax_generic;
use Z3950::ASN1::Z39_50_APDU_1995;
use Z3950::Z3950;

use Data::Dumper;

@::filenames = ();         # files to process
$::inputtype = 'BER';      # default type, could be XER as well

while ( $arg = shift @ARGV ) {
   if ( $arg eq '-I' and $filename = shift @ARGV ) {
      push @filenames, $filename;
   } elsif ( $arg eq '-i' and $::inputtype = uc(shift @ARGV) ) {
      # NOP
   } elsif ( $arg eq '-D' and $debuglist = shift @ARGV ) {
      $ASN1::debug = $::debug = 1
         if $debuglist =~ m/\bmain\b/i;
      $ASN1::debug_received = 1
         if $debuglist =~ m/\breceived\b/i;
      $ASN1::debug_sent = 1
         if $debuglist =~ m/\bsent\b/i;
      $ASN1::BER::debug = $ASN1::BER::debug_stacking = 1
         if $debuglist =~ m/\bBER\b/i;
      $ASN1::XER::debug = $ASN1::XER::debug_stacking = 1
         if $debuglist =~ m/\bXER\b/i;
      $Z3950::debug = 1
         if $debuglist =~ m/\bZ(39\.?50)?\b/i;
   } else {
      die "Syntax: $0 [options]\n"
        . " with  -D    a comma separated list of (main,received,sent,BER,XER,Z) []\n"
        . "       -i    type of PDU (XER,BER) [$::inputtype]\n"
        . "       -I    name of file to display [], repeatable\n";
   }
}

die "No filenames specified"
   if !@filenames;


FILE: foreach $filename (@filenames) {
   print substr($filename . ' ' . ('-'x80), 0, 79) ."\n"
      if $#filenames > 0 or $::debug;

   if (!open IN, $filename) {
      warn "Could not open $filename for reading, $!";
      next FILE;
   }

   $PDU = &ASN1::receivePDU(\*IN, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $::inputtype, $filename)
      or warn $@;
   
   $Data::Dumper::Indent = 1;

   $s = Dumper($PDU);
   $s =~ tr/\x08\x0a\x0d\x20-\x7f/./c;
   print $s;
}
