#!/usr/local/bin/perl

# small script to display (a subset of) the list of OID's
# stored in ASN1::OID_descriptions
#
# the modules are used on the fly

use ASN1;

$::debug = 0;     # switch debugging of main off by default
@filters = ();
@modules = ();

while ( $arg = shift @ARGV ) {
   if ( $arg eq '-d' ) {
      $::debug = 1;
   } elsif ( $arg eq '-u' and $module = shift @ARGV ) {
      push @modules, $modules;
   } elsif ( $arg =~ m/^[^-]/ and $arg ) {
      push @filters, $arg;
      warn "added filter '$arg'"
         if $::debug;
   } else {
      warn "Syntax error: $arg ".join(' ', @ARGV)
         unless $arg eq '-h' or $arg eq '-?';
      die "Syntax: $0 [options] [words to select on, OR-d]\n"
         . "with options\n"
         . "   -d    switch on debugging\n"
         . "   -u    name of module to be 'use'-d / 'require'-d\n";
   }
}

@modules = `grep -l 'ASN1::OID_descriptions' *.pm`
   unless @modules;

foreach $module ( @modules ) {
   chomp $module;
   if ( eval "use $module" or eval "require '$module'" or eval "require '$module.pm'" ) {
      warn "loaded $module"
         if $::debug;
   } else {
      warn "failed to load $module"
         if $::debug;
   }
}

OID: foreach $oid ( keys %ASN1::OID_descriptions ) {
   $display = 1;
   FILTER: foreach $filter ( @filters ) {
      $display = 0;
      if ( $oid =~ m/$filter/ or $ASN1::OID_descriptions{$oid} =~ m/$filter/i ) {
         $display = 1;
         last FILTER;
      }
   }

   next OID
      if !$display;

   print "$oid $ASN1::OID_descriptions{$oid}\n";
}
