#!/usr/local/bin/perl
# * ====================================================================
# * Copyright (c) 1995,1996, ISIS/JRC.  All rights reserved.
# *
# * This product was developed within the Institute for Safety, Informatics
# * and Systems of the Joint Research Centre of the European Commission.
# *
# * More information about us; and this software product can
# * be found on http://www.jrc.it.
# *
# * With this file you should have received a file called 'License'.
# *
# * Redistribution and use in source and binary forms, with or without
# * modification, are permitted provided that the following conditions
# * are met:
# *
# * 1. Redistributions of source code must retain the above copyright
# *    notice, this list of conditions and the following disclaimer.
# *
# * 2. Redistributions in binary form must reproduce the above copyright
# *    notice, this list of conditions and the following disclaimer in
# *    the documentation and/or other materials provided with the
# *    distribution.
# *
# * 3. All materials mentioning features or use of this
# *    software must display the following acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * 4. The name of the Copyright holder must not be used to
# *    endorse or promote products derived from this software without
# *    prior written permission.
# *
# * 5. Redistributions of any form whatsoever must retain the following
# *    acknowledgment:
# *    "This product includes software developed by ISIS/JRC"
# *
# * THIS SOFTWARE IS PROVIDED BY ISIS/JRC ``AS IS'' AND ANY
# * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ISIS/JRC OR
# * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
# * OF THE POSSIBILITY OF SUCH DAMAGE.
# * ====================================================================

use FileHandle;
use Socket;

use ASN1;
use Z3950::ASN1::Z39_50_APDU_1995;

use Z3950::Z3950;


$::host = undef;              # remote host to query
$::port = 210;                # port the remote database is located on
$::dbase = undef;             # database to search in
$::fieldname = 'any';         # default field to be searched
$::attributeset = '1.2.840.10003.3.1';    # Bib-1 attribute set
$::string = undef;            # string to search on
$::inputtype = 'XER';         # default inputtype, can be XER or BER
$::username = undef;
$::password = undef;

$::debug = 0;                 # switch on/off debugging output and checks

while ( $arg = shift @ARGV ) {
   if ( $arg eq '-p' and $::port = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-h' and $::host = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-d' and $::dbase = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-f' and $::fieldname = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-a' and $::attributeset = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-D' and $debuglist = shift @ARGV ) {
      $ASN1::debug = $::debug = 1
         if $debuglist =~ s/\bmain\b//gi;
      $ASN1::debug_received = 1
         if $debuglist =~ s/\breceived\b//gi;
      $ASN1::debug_sent = 1
         if $debuglist =~ s/\bsent\b//ig;
      $ASN1::BER::debug = 1
         if $debuglist =~ s/\bBER\b//ig;
      $ASN1::XER::debug = 1
         if $debuglist =~ s/\bXER\b//gi;
      $debuglist =~ s/[\s,.]//gi;
      warn "Unrecognised debug options: $debuglist"
         if $debuglist;
   } elsif ( $arg eq '-s' and $::string = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-i' and $::inputtype = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-t' and $ASN1::CONNECTION_TIMEOUT = shift @ARGV ) {
      # nop
   } elsif ( $arg eq '-u' and $::username = shift @ARGV and $::password = shift @ARGV ) {
      # nop
   } else {
      if ( $arg eq '-h' or $arg eq '-?' ) {
         &usage();
      } else {
         &usage("Syntax error: $arg ".join(' ', @ARGV))
      }
   }
}

&usage("No host specified")
   unless $::host;
&usage("No port specified")
   unless $::port;
&usage("No database specified")
   unless $::dbase;
&usage("No search string specified")
   unless $::string;
&usage("No inputtype specified")
   unless $::inputtype;

# Create a socket to the other end we want to talk to
#
my $socket = new FileHandle;
my $proto = getprotobyname('tcp')
   or die "getprotobyname failed, $!";
socket($socket, PF_INET, SOCK_STREAM, $proto)
   or die "socket failed, $!";
my $addr = inet_aton($::host)
   or die "inet_aton failed, $!";
my $addr_in = sockaddr_in($::port, $addr)
   or die "sockaddr_in failed, $!";
connect($socket, $addr_in)
   or die "connect failed, $!";
select((select($socket), $| = 1)[0]);


print "Connected to $::host:$::port.$::inputtype\n";

# Prepare initRequest
#
$IQ->{protocolVersion} = "version-1 version-2";
$IQ->{options} = "search present";
$IQ->{preferredMessageSize} = 100000;
$IQ->{exceptionalRecordSize} = 100000;
$IQ->{implementationId} = "test_client (id=116)";
$IQ->{implementationName} = "test_client";
$IQ->{implementationVersion} = "v0.0";
if ( $::username or $::password ) {
   $IQ->{idAuthentication}->{idPass}->{userId} = 'elephant';
   $IQ->{idAuthentication}->{idPass}->{password} = 'hqocGyXhORY';
}

# Send it
#
print "Sending IQ\n";
&ASN1::sendPDU($socket, {initRequest=>$IQ}, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $::inputtype, 'IQ')
   or die $@;


# Receive the InitResponse
#
print "Receiving IS\n";
my $IS = &ASN1::receivePDU($socket, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $::inputtype, 'IS')
   or die $@;

# Print some bits and pieces from the structure
#
print "Contacted: $IS->{initResponse}->{implementationName} $IS->{initResponse}->{implementationVersion} "
    . "($IS->{initResponse}->{implementationVersion})\n";


print "searching for '$::string' in $::fieldname field (OID $::attributeset) in dbase $::dbase\n";

# Prepare the SearchRequest
#
$SQ->{smallSetUpperBound} = 0;
$SQ->{largeSetLowerBound} = 1;
$SQ->{mediumSetPresentNumber} = 0;
$SQ->{replaceIndicator} = 'true';
$SQ->{resultSetName} = 'default';
$SQ->{databaseNames} = [$::dbase];

# the query
$SQ->{query}->{'type-1'}->{attributeSet} = $::attributeset;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[0]->{attributeSet} = $::attributeset;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[0]->{attributeType} = $Z3950::Bib1_Use_Type;
if ( $::fieldname =~ m/[^0-9]/ ) {
   $SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[0]->{attributeValue}->{numeric} = $Z3950::Bib1_Use{$::fieldname};
} else {
   # assume that it is a numeric ID
   $SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[0]->{attributeValue}->{numeric} = $::fieldname;
}
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[1]->{attributeSet} = $Z3950::OID_AS_Bib1;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[1]->{attributeType} = $Z3950::Bib1_Relation_Type;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[1]->{attributeValue}->{numeric} = $Z3950::Bib1_Relation{equal};
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[2]->{attributeSet} = $Z3950::OID_AS_Bib1;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[2]->{attributeType} = $Z3950::Bib1_Position_Type;
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{attributes}->[2]->{attributeValue}->{numeric} = $Z3950::Bib1_Position{'any position in field'};
$SQ->{query}->{'type-1'}->{rpn}->{op}->{attrTerm}->{term}->{general} = $::string;

# and send it
#
print "Sending SQ\n";
&ASN1::sendPDU($socket, {searchRequest=>$SQ}, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $::inputtype, 'SQ')
   or die $@;

# receive the SearchResponse
#
print "Receiving SS\n";
my $SS = &ASN1::receivePDU($socket, \%Z3950::ASN1::Z39_50_APDU_1995::PDU, $::inputtype, 'SS')
   or die $@;

$SS = $SS->{searchResponse}
   or die "Returned record is not searchResponse";     

if ( $SS->{searchStatus} eq 'true' ) {
   print "Search for $::string gave $SS->{resultCount} hits";
   if ( $SS->{presentStatus} ) {
      print ",\n present was a $SS->{presentStatus}";
      print " with $SS->{numberOfRecordsReturned} results returned\n";

      if ( $SS->{numberOfRecordsReturned} ) {
           eval 'use Data::Dumper;';
           $Data::Dumper::Indent = 1;
           print Dumper($SS->{records})
            unless $@;
      }
   } else {
      print ".\n";
   }
} else {
   print "Search failed (use '-D received' to write the received PDU to file and\n";
   print "use dump_pdu -i $::inputtype -I filename to display its contents.\n";
   print "Most probably there is a diagnostic in there.)\n";
}

# End of story
#
close $socket;

sub usage {
   my (@msgs) = @_;

   print STDERR join("\n", @msgs) . "\n"
      if @msgs;

   die "Syntax: $0 [options]\n"
     . " with  -D    a comma separated list of (main,received,sent,BER,XER) []\n"
     . "       -a    OID of attribute set [$::attributeset]\n"
     . "       -d    database on destination [$::dbase]\n"
     . "       -f    fieldname to search [$::fieldname]\n"
     . "       -h    name of host to contact [$::host]\n"
     . "       -i    type of connection (XER,BER) [$::inputtype]\n"
     . "       -p    port [$::port]\n"
     . "       -s    string to search for in any field on destination ['$::string']\n"
     . "       -t    timeout for requests [$ASN1::CONNECTION_TIMEOUT]\n"
     . "       -u    username and password to use during init [$::username, $::password]\n";
}
